@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -27,7 +27,6 @@ from ax.core import (
     RangeParameter,
     Runner,
     SearchSpace,
-    SimpleExperiment,
     SumConstraint,
     Trial,
 )
@@ -36,12 +35,6 @@ from ax.service import OptimizationLoop, optimize
 from ax.storage import json_load, json_save
 
 
-try:
-    # pyre-fixme[21]: Could not find a module... to import `ax.version`.
-    from ax.version import version as __version__
-except Exception:
-    __version__ = "Unknown"
-
 __all__ = [
     "Arm",
     "BatchTrial",
@@ -67,7 +60,6 @@ __all__ = [
     "RangeParameter",
     "Runner",
     "SearchSpace",
-    "SimpleExperiment",
     "SumConstraint",
     "Trial",
     "optimize",
