@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -34,9 +34,10 @@ from ax.core.parameter_constraint import (
     ParameterConstraint,
     SumConstraint,
 )
+from ax.core.parameter_distribution import ParameterDistribution
+from ax.core.risk_measures import RiskMeasure
 from ax.core.runner import Runner
 from ax.core.search_space import SearchSpace
-from ax.core.simple_experiment import SimpleExperiment, TEvaluationOutcome
 from ax.core.trial import Trial
 from ax.core.types import TParameterization
 
@@ -60,8 +61,10 @@ __all__ = [
     "OutcomeConstraint",
     "Parameter",
     "ParameterConstraint",
+    "ParameterDistribution",
     "ParameterType",
     "RangeParameter",
+    "RiskMeasure",
     "Runner",
     "SearchSpace",
     "SimpleExperiment",
