@@ -7,8 +7,9 @@
 from __future__ import annotations
 
 import json
+from functools import reduce
 from hashlib import md5
-from typing import Any, Dict, Iterable, Optional, Set, Type
+from typing import Any, Dict, Iterable, Optional, Set, Type, Union
 
 import numpy as np
 import pandas as pd
@@ -226,6 +227,48 @@ class Data(Base, SerializationMixin):
         """
         return set() if self.df.empty else set(self.df["metric_name"].values)
 
+    def filter(
+        self,
+        trial_indices: Optional[Iterable[int]] = None,
+        metric_names: Optional[Iterable[str]] = None,
+    ) -> Data:
+        """Construct a new Data object with the subset of rows corresponding to the
+        provided trial indices AND metric names. If either trial_indices or
+        metric_names are not provided, that dimension will not be filtered.
+        """
+
+        return Data(
+            df=self._filter_df(
+                df=self.df, trial_indices=trial_indices, metric_names=metric_names
+            )
+        )
+
+    @staticmethod
+    def _filter_df(
+        df: pd.DataFrame,
+        trial_indices: Optional[Iterable[int]] = None,
+        metric_names: Optional[Iterable[str]] = None,
+    ) -> pd.DataFrame:
+        trial_indices_mask = (
+            reduce(
+                lambda left, right: left | right,
+                [df["trial_index"] == trial_index for trial_index in trial_indices],
+            )
+            if trial_indices is not None
+            else pd.Series([True] * len(df))
+        )
+
+        metric_names_mask = (
+            reduce(
+                lambda left, right: left | right,
+                [df["metric_name"] == metric_name for metric_name in metric_names],
+            )
+            if metric_names is not None
+            else pd.Series([True] * len(df))
+        )
+
+        return df.loc[trial_indices_mask & metric_names_mask]
+
     def get_filtered_results(self, **filters: Dict[str, Any]) -> pd.DataFrame:
         """Return filtered subset of data.
 
@@ -274,8 +317,8 @@ class Data(Base, SerializationMixin):
         evaluations: Dict[str, TTrialEvaluation],
         trial_index: int,
         sample_sizes: Optional[Dict[str, int]] = None,
-        start_time: Optional[int] = None,
-        end_time: Optional[int] = None,
+        start_time: Optional[Union[int, str]] = None,
+        end_time: Optional[Union[int, str]] = None,
     ) -> Data:
         """
         Convert dict of evaluations to Ax data object.
@@ -287,9 +330,13 @@ class Data(Base, SerializationMixin):
             trial_index: Trial index to which this data belongs.
             sample_sizes: Number of samples collected for each arm.
             start_time: Optional start time of run of the trial that produced this
-                data, in milliseconds.
+                data, in milliseconds or iso format.  Milliseconds will be automatically
+                converted to iso format because iso format automatically works with the
+                pandas column type `Timestamp`.
             end_time: Optional end time of run of the trial that produced this
-                data, in milliseconds.
+                data, in milliseconds or iso format.  Milliseconds will be automatically
+                converted to iso format because iso format automatically works with the
+                pandas column type `Timestamp`.
 
         Returns:
             Ax Data object.
@@ -306,6 +353,11 @@ class Data(Base, SerializationMixin):
             for metric_name, value in evaluation.items()
         ]
         if start_time is not None or end_time is not None:
+            if isinstance(start_time, int):
+                start_time = _ms_epoch_to_isoformat(start_time)
+            if isinstance(end_time, int):
+                end_time = _ms_epoch_to_isoformat(end_time)
+
             for record in records:
                 record.update({"start_time": start_time, "end_time": end_time})
         if sample_sizes:
@@ -399,6 +451,10 @@ def clone_without_metrics(data: Data, excluded_metric_names: Iterable[str]) -> D
     )
 
 
+def _ms_epoch_to_isoformat(epoch: int) -> str:
+    return pd.Timestamp(epoch, unit="ms").isoformat()
+
+
 def custom_data_class(
     # pyre-fixme[24]: Generic type `type` expects 1 type parameter, use
     #  `typing.Type` to avoid runtime subscripting errors.
