@@ -324,8 +324,7 @@ class Experiment(Base):
             self._default_data_type = DataType.MAP_DATA
 
     @property
-    # pyre-fixme[24]: Generic type `OrderedDict` expects 2 type parameters.
-    def data_by_trial(self) -> Dict[int, OrderedDict]:
+    def data_by_trial(self) -> Dict[int, OrderedDict[int, Data]]:
         """Data stored on the experiment, indexed by trial index and storage time.
 
         First key is trial index and second key is storage time in milliseconds.
@@ -527,6 +526,9 @@ class Experiment(Base):
         available while trial is running is determined by the boolean returned from its
         `is_available_while_running` class method.
 
+        NOTE: This can be lossy (ex. a MapData could get implicitly cast to a Data and
+        lose rows) if Experiment.default_data_type is misconfigured!
+
         Args:
             metrics: If provided, fetch data for these metrics instead of the ones
                 defined on the experiment.
@@ -568,6 +570,9 @@ class Experiment(Base):
         available while trial is running is determined by the boolean returned from its
         `is_available_while_running` class method.
 
+        NOTE: This can be lossy (ex. a MapData could get implicitly cast to a Data and
+        lose rows) if Experiment.default_data_type is misconfigured!
+
         Args:
             trial_indices: Indices of trials, for which to fetch data.
             metrics: If provided, fetch data for these metrics instead of the ones
@@ -1101,8 +1106,8 @@ class Experiment(Base):
             copy_run_metadata_keys: A list of keys denoting which items to copy over
                 from each trial's run_metadata.
             trial_statuses_to_copy: All trials with a status in this list will be
-                copied. By default, copies all ``COMPLETED``, ``ABANDONED``, and
-                ``EARLY_STOPPED`` trials.
+                copied. By default, copies all ``RUNNING``, ``COMPLETED``,
+                ``ABANDONED``, and ``EARLY_STOPPED`` trials.
 
         Returns:
             List of trials successfully copied from old_experiment to this one
@@ -1147,12 +1152,22 @@ class Experiment(Base):
             dat, ts = old_experiment.lookup_data_for_trial(trial_index=trial.index)
             # Set trial index and arm name to their values in new trial.
             new_trial = self.new_trial()
-            add_arm_and_maybe_clear_name(new_trial=new_trial, old_trial=trial)
+            add_arm_and_prevent_naming_collision(
+                new_trial=new_trial,
+                old_trial=trial,
+                old_experiment_name=old_experiment._name,
+            )
             new_trial.mark_running(no_runner_required=True)
             new_trial._properties["source"] = (
                 f"Warm start from Experiment: `{old_experiment._name}`, "
                 f"trial: `{trial.index}`"
             )
+            # Associates a generation_model_key to the new trial.
+            generation_model_key = trial._properties.get("generation_model_key")
+            if generation_model_key is None and trial.generator_run is not None:
+                generation_model_key = trial.generator_run._model_key or "Manual"
+            new_trial._properties["generation_model_key"] = generation_model_key
+
             if copy_run_metadata_keys is not None:
                 for run_metadata_field in copy_run_metadata_keys:
                     new_trial.update_run_metadata(
@@ -1288,14 +1303,22 @@ class Experiment(Base):
         return trial_type is None
 
 
-def add_arm_and_maybe_clear_name(new_trial: Trial, old_trial: Trial) -> None:
-    # Clear name only if it matches auto-generated format.
+def add_arm_and_prevent_naming_collision(
+    new_trial: Trial, old_trial: Trial, old_experiment_name: Optional[str] = None
+) -> None:
+    # Add all of an old trial's arms to a new trial. Rename any arm with auto-generated
+    # naming format to prevent naming collisions during warm-start. If an old
+    # experiment name is provided, append that to the original arm name. Else, clear
+    # the arm name. Preserves all names not matching the automatic naming format.
+    # experiment is not named, clear the arm's name.
     # `arm_index` is 0 since all trials are single-armed.
-    clear_name = bool(
-        not_none(old_trial.arm).name == old_trial._get_default_name(arm_index=0)
-    )
-    if clear_name:
-        new_trial.add_arm(not_none(old_trial.arm).clone(clear_name=True))
+    old_arm_name = not_none(old_trial.arm).name
+    has_default_name = bool(old_arm_name == old_trial._get_default_name(arm_index=0))
+    if has_default_name:
+        new_arm = not_none(old_trial.arm).clone(clear_name=True)
+        if old_experiment_name is not None:
+            new_arm.name = f"{old_arm_name}_{old_experiment_name}"
+        new_trial.add_arm(new_arm)
     else:
         try:
             new_trial.add_arm(not_none(old_trial.arm).clone(clear_name=False))
