@@ -6,7 +6,10 @@
 
 from __future__ import annotations
 
+import traceback
+
 from dataclasses import dataclass
+from functools import reduce
 from logging import Logger
 
 from typing import (
@@ -24,7 +27,7 @@ from typing import (
 from ax.core.data import Data
 from ax.utils.common.base import SortableBase
 from ax.utils.common.logger import get_logger
-from ax.utils.common.result import Err, Ok, Result
+from ax.utils.common.result import Err, Ok, Result, UnwrapError
 from ax.utils.common.serialization import SerializationMixin
 
 if TYPE_CHECKING:  # pragma: no cover
@@ -32,16 +35,44 @@ if TYPE_CHECKING:  # pragma: no cover
     from ax import core  # noqa F401
 
 
+logger: Logger = get_logger(__name__)
+
+
 @dataclass(frozen=True)
 class MetricFetchE:
+    # NOTE/TODO[mpolson64]: This could probably be generalized to a
+    # `PythonExceptionE` class in the future. Let's do our best to avoid
+    # reinventing the wheel in the next `Result` use case in Ax.
+
     message: str
     exception: Optional[Exception]
 
+    def __post_init__(self) -> None:
+        logger.info(msg=f"MetricFetchE INFO: Initialized {self}")
+
+    def __repr__(self) -> str:
+        if self.exception is None:
+            return f'MetricFetchE(message="{self.message}")'
+
+        return (
+            f'MetricFetchE(message="{self.message}", exception={self.exception})\n'
+            f"with Traceback:\n {self.tb_str()}"
+        )
+
+    def tb_str(self) -> Optional[str]:
+        if self.exception is None:
+            return None
+
+        return reduce(
+            lambda left, right: left + right,
+            traceback.format_exception(
+                None, self.exception, self.exception.__traceback__
+            ),
+        )
+
 
 MetricFetchResult = Result[Data, MetricFetchE]
 
-logger: Logger = get_logger(__name__)
-
 
 class Metric(SortableBase, SerializationMixin):
     """Base class for representing metrics.
@@ -286,6 +317,10 @@ class Metric(SortableBase, SerializationMixin):
 
     @classmethod
     def _unwrap_experiment_data(cls, results: Mapping[int, MetricFetchResult]) -> Data:
+        # NOTE: This can be lossy (ex. a MapData could get implicitly cast to a Data and
+        # lose rows)if some MetricFetchResults contain Data not of type
+        # `cls.data_constructor`
+
         oks: List[Ok[Data, MetricFetchE]] = [
             result for result in results.values() if isinstance(result, Ok)
         ]
@@ -301,7 +336,10 @@ class Metric(SortableBase, SerializationMixin):
                 else Exception(err.err.message)
                 for err in errs
             ]
-            raise exceptions[0] if len(exceptions) == 1 else Exception(exceptions)
+
+            raise UnwrapError(errs) from (
+                exceptions[0] if len(exceptions) == 1 else Exception(exceptions)
+            )
 
         data = [ok.ok for ok in oks]
         return (
@@ -317,6 +355,10 @@ class Metric(SortableBase, SerializationMixin):
         # TODO[mpolson64] Add critical_metric_names to other unwrap methods
         critical_metric_names: Optional[Iterable[str]] = None,
     ) -> Data:
+        # NOTE: This can be lossy (ex. a MapData could get implicitly cast to a Data and
+        # lose rows)if some MetricFetchResults contain Data not of type
+        # `cls.data_constructor`
+
         oks: List[Ok[Data, MetricFetchE]] = [
             result for result in results.values() if isinstance(result, Ok)
         ]
@@ -353,7 +395,9 @@ class Metric(SortableBase, SerializationMixin):
                     else Exception(err.err.message)
                     for err in critical_errs
                 ]
-                raise exceptions[0] if len(exceptions) == 1 else Exception(exceptions)
+                raise UnwrapError(critical_errs) from (
+                    exceptions[0] if len(exceptions) == 1 else Exception(exceptions)
+                )
 
         data = [ok.ok for ok in oks]
 
@@ -368,6 +412,10 @@ class Metric(SortableBase, SerializationMixin):
         cls,
         results: Mapping[int, Mapping[str, MetricFetchResult]],
     ) -> Data:
+        # NOTE: This can be lossy (ex. a MapData could get implicitly cast to a Data and
+        # lose rows)if some MetricFetchResults contain Data not of type
+        # `cls.data_constructor`
+
         flattened = [
             result for sublist in results.values() for result in sublist.values()
         ]
@@ -386,7 +434,9 @@ class Metric(SortableBase, SerializationMixin):
                 else Exception(err.err.message)
                 for err in errs
             ]
-            raise exceptions[0] if len(exceptions) == 1 else Exception(exceptions)
+            raise UnwrapError(errs) from (
+                exceptions[0] if len(exceptions) == 1 else Exception(exceptions)
+            )
 
         data = [ok.ok for ok in oks]
         return (
@@ -398,22 +448,14 @@ class Metric(SortableBase, SerializationMixin):
     @classmethod
     def _wrap_experiment_data(cls, data: Data) -> Dict[int, MetricFetchResult]:
         return {
-            trial_index: Ok(
-                value=Data(
-                    df=data.true_df.loc[data.true_df["trial_index"] == trial_index]
-                )
-            )
+            trial_index: Ok(value=data.filter(trial_indices=[trial_index]))
             for trial_index in data.true_df["trial_index"]
         }
 
     @classmethod
     def _wrap_trial_data_multi(cls, data: Data) -> Dict[str, MetricFetchResult]:
         return {
-            metric_name: Ok(
-                value=Data(
-                    df=data.true_df.loc[data.true_df["metric_name"] == metric_name]
-                )
-            )
+            metric_name: Ok(value=data.filter(metric_names=[metric_name]))
             for metric_name in data.true_df["metric_name"]
         }
 
@@ -425,11 +467,8 @@ class Metric(SortableBase, SerializationMixin):
         return {
             trial_index: {
                 metric_name: Ok(
-                    value=Data(
-                        df=data.true_df.loc[
-                            (data.true_df["trial_index"] == trial_index)
-                            & (data.true_df["metric_name"] == metric_name)
-                        ]
+                    value=data.filter(
+                        trial_indices=[trial_index], metric_names=[metric_name]
                     )
                 )
                 for metric_name in data.true_df["metric_name"]
