@@ -20,6 +20,7 @@ from ax.core.parameter import FixedParameter, ParameterType
 from ax.core.search_space import SearchSpace
 from ax.exceptions.core import UnsupportedError
 from ax.metrics.branin import BraninMetric
+from ax.modelbridge.registry import Models
 from ax.runners.synthetic import SyntheticRunner
 from ax.service.ax_client import AxClient
 from ax.utils.common.constants import EXPERIMENT_IS_TEST_WARNING, Keys
@@ -391,7 +392,7 @@ class ExperimentTest(TestCase):
         batch.mark_completed()
 
         # Test fetch data
-        batch_data = Metric._unwrap_trial_data_multi(results=batch.fetch_data())
+        batch_data = batch.fetch_data()
         self.assertEqual(len(batch_data.df), n)
 
         exp_data = exp.fetch_data()
@@ -470,9 +471,7 @@ class ExperimentTest(TestCase):
 
         # Verify we don't get the data if the trial is abandoned
         batch._status = TrialStatus.ABANDONED
-        self.assertEqual(
-            len(Metric._unwrap_trial_data_multi(results=batch.fetch_data()).df), 0
-        )
+        self.assertEqual(len(batch.fetch_data().df), 0)
         self.assertEqual(len(exp.fetch_data().df), 3 * n)
 
         # Verify we do get the stored data if there are an unimplemented metrics.
@@ -483,13 +482,9 @@ class ExperimentTest(TestCase):
         exp.add_tracking_metric(Metric(name="b"))  # Add unimplemented metric.
         batch._status = TrialStatus.COMPLETED
         # Data should be getting looked up now.
-        self.assertEqual(batch.fetch_data()["b"].ok, exp.lookup_data_for_ts(t1))
+        self.assertEqual(batch.fetch_data(), exp.lookup_data_for_ts(t1))
         self.assertEqual(exp.fetch_data(), exp.lookup_data_for_ts(t1))
-        metrics_in_data = set(
-            Metric._unwrap_trial_data_multi(results=batch.fetch_data())
-            .df["metric_name"]
-            .values
-        )
+        metrics_in_data = set(batch.fetch_data().df["metric_name"].values)
         # Data for metric "z" should no longer be present since we removed it.
         self.assertEqual(metrics_in_data, {"b"})
 
@@ -796,13 +791,14 @@ class ExperimentTest(TestCase):
         )
         self.assertEqual(len(new_experiment.trials), len(old_experiment.trials) - 1)
         i_old_trial = 0
-        for _, trial in new_experiment.trials.items():
+        for idx, trial in new_experiment.trials.items():
             # skip failed trial
             i_old_trial += i_old_trial == i_failed_trial
+            # pyre-fixme[16]: `BaseTrial` has no attribute `arm`.
+            old_arm = old_experiment.trials[i_old_trial].arm
             self.assertEqual(
-                # pyre-fixme[16]: `BaseTrial` has no attribute `arm`.
                 trial.arm.parameters,
-                old_experiment.trials[i_old_trial].arm.parameters,
+                old_arm.parameters,
             )
             self.assertRegex(
                 trial._properties["source"], "Warm start.*Experiment.*trial"
@@ -810,6 +806,14 @@ class ExperimentTest(TestCase):
             self.assertDictEqual(trial.run_metadata, DUMMY_RUN_METADATA)
             i_old_trial += 1
 
+            # Check naming logic.
+            if idx == 0:
+                self.assertEqual(trial.arm.name, DUMMY_ARM_NAME)
+            else:
+                self.assertEqual(
+                    trial.arm.name, f"{old_arm.name}_{old_experiment.name}"
+                )
+
         # Check that the data was attached for correct trials
         old_df = old_experiment.fetch_data().df
         new_df = new_experiment.fetch_data().df
@@ -820,9 +824,6 @@ class ExperimentTest(TestCase):
             new_df.drop(["arm_name", "trial_index"], axis=1),
         )
 
-        # Check name-preserving logic.
-        self.assertEqual(new_experiment.trials[0].arm.name, DUMMY_ARM_NAME)
-
         # check that all non-failed/abandoned trials are copied to new_experiment
         new_experiment = get_branin_experiment()
         # make metric noiseless for exact reproducibility
@@ -944,6 +945,22 @@ class ExperimentWithMapDataTest(TestCase):
         actual_data = self.experiment.lookup_data()
         self.assertEqual(expected_data, actual_data)
 
+    def testFetchDataWithMixedData(self) -> None:
+        with patch(
+            f"{BraninMetric.__module__}.BraninMetric.is_available_while_running",
+            return_value=False,
+        ):
+            exp = self._setupBraninExperiment(n=5)
+            [exp.trials[i].mark_completed() for i in range(len(exp.trials))]
+
+            # Fill cache with MapData
+            map_data = exp.fetch_data(metrics=[exp.metrics["branin_map"]])
+
+            # Fetch other metrics and merge Data into the cached MapData
+            full_data = exp.fetch_data()
+
+            self.assertEqual(len(full_data.true_df), len(map_data.true_df) + 20)
+
     def testFetchTrialsData(self) -> None:
         exp = self._setupBraninExperiment(n=5)
         batch_0 = exp.trials[0]
@@ -1042,6 +1059,9 @@ class ExperimentWithMapDataTest(TestCase):
             self.assertRegex(
                 trial._properties["source"], "Warm start.*Experiment.*trial"
             )
+            self.assertEqual(
+                trial._properties["generation_model_key"], Models.SOBOL.value
+            )
             self.assertDictEqual(trial.run_metadata, DUMMY_RUN_METADATA)
             i_old_trial += 1
 
