@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -21,7 +21,7 @@ GENERATOR_RUN_STR_PLUS_1 = "GeneratorRun(3 arms, total weight 4.0)"
 
 
 class GeneratorRunTest(TestCase):
-    def setUp(self):
+    def setUp(self) -> None:
         self.model_predictions = get_model_predictions()
         self.optimization_config = get_optimization_config()
         self.search_space = get_search_space()
@@ -38,18 +38,22 @@ class GeneratorRunTest(TestCase):
         )
         self.weighted_run = GeneratorRun(
             arms=self.arms,
+            # pyre-fixme[6]: For 2nd param expected `Optional[List[float]]` but got
+            #  `List[int]`.
             weights=self.weights,
             optimization_config=self.optimization_config,
             search_space=self.search_space,
             model_predictions=self.model_predictions,
         )
 
-    def testInit(self):
+    def testInit(self) -> None:
         self.assertEqual(
+            # pyre-fixme[16]: Optional type has no attribute `outcome_constraints`.
             len(self.unweighted_run.optimization_config.outcome_constraints),
             len(self.optimization_config.outcome_constraints),
         )
         self.assertEqual(
+            # pyre-fixme[16]: Optional type has no attribute `parameters`.
             len(self.unweighted_run.search_space.parameters),
             len(self.search_space.parameters),
         )
@@ -82,7 +86,7 @@ class GeneratorRunTest(TestCase):
                 },
             )
 
-    def testClone(self):
+    def testClone(self) -> None:
         weighted_run2 = self.weighted_run.clone()
         self.assertEqual(
             self.weighted_run.optimization_config, weighted_run2.optimization_config
@@ -90,7 +94,7 @@ class GeneratorRunTest(TestCase):
         weighted_run2.arms[0].name = "bogus_name"
         self.assertNotEqual(self.weighted_run.arms, weighted_run2.arms)
 
-    def testMergeDuplicateArm(self):
+    def testMergeDuplicateArm(self) -> None:
         arms = self.arms + [self.arms[0]]
         run = GeneratorRun(
             arms=arms,
@@ -100,13 +104,13 @@ class GeneratorRunTest(TestCase):
         )
         self.assertEqual(str(run), GENERATOR_RUN_STR_PLUS_1)
 
-    def testIndex(self):
+    def testIndex(self) -> None:
         self.assertIsNone(self.unweighted_run.index)
         self.unweighted_run.index = 1
         with self.assertRaises(ValueError):
             self.unweighted_run.index = 2
 
-    def testModelPredictions(self):
+    def testModelPredictions(self) -> None:
         self.assertEqual(self.unweighted_run.model_predictions, get_model_predictions())
         self.assertEqual(
             self.unweighted_run.model_predictions_by_arm,
@@ -114,6 +118,8 @@ class GeneratorRunTest(TestCase):
         )
         run_no_model_predictions = GeneratorRun(
             arms=self.arms,
+            # pyre-fixme[6]: For 2nd param expected `Optional[List[float]]` but got
+            #  `List[int]`.
             weights=self.weights,
             optimization_config=get_optimization_config(),
             search_space=get_search_space(),
@@ -121,7 +127,7 @@ class GeneratorRunTest(TestCase):
         self.assertIsNone(run_no_model_predictions.model_predictions)
         self.assertIsNone(run_no_model_predictions.model_predictions_by_arm)
 
-    def testEq(self):
+    def testEq(self) -> None:
         self.assertEqual(self.unweighted_run, self.unweighted_run)
 
         arms = [
@@ -135,13 +141,15 @@ class GeneratorRunTest(TestCase):
         )
         self.assertNotEqual(self.unweighted_run, unweighted_run_2)
 
-    def testParamDf(self):
+    def testParamDf(self) -> None:
         param_df = self.unweighted_run.param_df
         self.assertEqual(len(param_df), len(self.arms))
 
-    def testBestArm(self):
+    def testBestArm(self) -> None:
         generator_run = GeneratorRun(
             arms=self.arms,
+            # pyre-fixme[6]: For 2nd param expected `Optional[List[float]]` but got
+            #  `List[int]`.
             weights=self.weights,
             optimization_config=get_optimization_config(),
             search_space=get_search_space(),
@@ -152,10 +160,12 @@ class GeneratorRunTest(TestCase):
             (self.arms[0], ({"a": 1.0}, {"a": {"a": 2.0}})),
         )
 
-    def testGenMetadata(self):
+    def testGenMetadata(self) -> None:
         gm = {"hello": "world"}
         generator_run = GeneratorRun(
             arms=self.arms,
+            # pyre-fixme[6]: For 2nd param expected `Optional[List[float]]` but got
+            #  `List[int]`.
             weights=self.weights,
             optimization_config=get_optimization_config(),
             search_space=get_search_space(),
@@ -163,13 +173,17 @@ class GeneratorRunTest(TestCase):
         )
         self.assertEqual(generator_run.gen_metadata, gm)
 
-    def testSortable(self):
+    def testSortable(self) -> None:
         generator_run1 = GeneratorRun(
             arms=self.arms,
+            # pyre-fixme[6]: For 2nd param expected `Optional[List[float]]` but got
+            #  `List[int]`.
             weights=self.weights,
         )
         generator_run2 = GeneratorRun(
             arms=self.arms,
+            # pyre-fixme[6]: For 2nd param expected `Optional[List[float]]` but got
+            #  `List[int]`.
             weights=self.weights,
         )
         generator_run1.index = 1
