@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -9,7 +9,7 @@ from ax.utils.common.testutils import TestCase
 
 
 class TypesTest(TestCase):
-    def setUp(self):
+    def setUp(self) -> None:
         self.num_arms = 2
         mu = {"m1": [0.0, 0.5], "m2": [0.1, 0.6]}
         cov = {
@@ -18,7 +18,7 @@ class TypesTest(TestCase):
         }
         self.predict = (mu, cov)
 
-    def testMergeModelPredict(self):
+    def testMergeModelPredict(self) -> None:
         mu_append = {"m1": [0.6], "m2": [0.7]}
         cov_append = {
             "m1": {"m1": [0.0], "m2": [0.0]},
@@ -27,7 +27,7 @@ class TypesTest(TestCase):
         merged_predicts = merge_model_predict(self.predict, (mu_append, cov_append))
         self.assertEqual(len(merged_predicts[0]["m1"]), 3)
 
-    def testMergeModelPredictFail(self):
+    def testMergeModelPredictFail(self) -> None:
         mu_append = {"m1": [0.6]}
         cov_append = {
             "m1": {"m1": [0.0], "m2": [0.0]},
