@@ -25,6 +25,7 @@ from ax.modelbridge.modelbridge_utils import (
 
 from ax.modelbridge.registry import Cont_X_trans, Y_trans
 from ax.modelbridge.transforms.base import Transform
+from ax.modelbridge.transforms.map_unit_x import MapUnitX
 
 from ax.models.torch_base import TorchModel
 from ax.utils.common.base import Base
@@ -65,6 +66,7 @@ class BaseEarlyStoppingStrategy(ABC, Base):
         metric_names: Optional[Iterable[str]] = None,
         seconds_between_polls: int = 300,
         min_progression: Optional[float] = None,
+        max_progression: Optional[float] = None,
         min_curves: Optional[int] = None,
         trial_indices_to_ignore: Optional[List[int]] = None,
         true_objective_metric_name: Optional[str] = None,
@@ -81,6 +83,8 @@ class BaseEarlyStoppingStrategy(ABC, Base):
                 (e.g. timestamp, epochs, training data used) is greater than this
                 threshold. Prevents stopping prematurely before enough data is gathered
                 to make a decision.
+            max_progression: Do not stop trials that have passed `max_progression`.
+                Useful if we prefer finishing a trial that are already near completion.
             min_curves: There must be `min_curves` number of completed trials and
                 `min_curves` number of trials with curve data to make a stopping
                 decision (i.e., even if there are enough completed trials but not all
@@ -102,6 +106,7 @@ class BaseEarlyStoppingStrategy(ABC, Base):
         self.metric_names = metric_names
         self.seconds_between_polls = seconds_between_polls
         self.min_progression = min_progression
+        self.max_progression = max_progression
         self.min_curves = min_curves
         self.trial_indices_to_ignore = trial_indices_to_ignore
         self.true_objective_metric_name = true_objective_metric_name
@@ -175,13 +180,11 @@ class BaseEarlyStoppingStrategy(ABC, Base):
             for map_key in map_keys:
                 values = map_df[map_key].astype(float)
                 map_df[map_key] = values / values.abs().max()
-
-            data = MapData(
-                df=map_df,
-                map_key_infos=data.map_key_infos,
-                description=data.description,
-            )
-        return data
+        return MapData(
+            df=map_df,
+            map_key_infos=data.map_key_infos,
+            description=data.description,
+        )
 
     @staticmethod
     def _log_and_return_trial_ignored(
@@ -207,25 +210,22 @@ class BaseEarlyStoppingStrategy(ABC, Base):
         return False, "No data available to make an early stopping decision."
 
     @staticmethod
-    def _log_and_return_min_progression(
+    def _log_and_return_progression_range(
         logger: logging.Logger,
-        trial_index: Optional[int],
+        trial_index: int,
         trial_last_progression: float,
-        min_progression: float,
+        min_progression: Optional[float],
+        max_progression: Optional[float],
     ) -> Tuple[bool, str]:
         """Helper function for logging/constructing a reason when min progression
         is not yet reached."""
         reason = (
-            f"Most recent progression ({trial_last_progression}) is less than "
-            "the specified minimum progression for early stopping "
-            f"({min_progression}). "
+            f"Most recent progression ({trial_last_progression}) falls out of the "
+            f"min/max_progression range ({min_progression}, {max_progression})."
+        )
+        logger.info(
+            f"Trial {trial_index}'s m{reason[1:]} Not early stopping this trial."
         )
-        if trial_index is not None:
-            logger.info(
-                f"Trial {trial_index}'s m{reason[1:]} Not early stopping this trial."
-            )
-        else:
-            logger.info("Not early stopping any trials.")
         return False, reason
 
     @staticmethod
@@ -304,11 +304,9 @@ class BaseEarlyStoppingStrategy(ABC, Base):
             f"Last progression of any candidate for trial stopping is {any_last_prog}."
         )
         if self.min_progression is not None and any_last_prog < self.min_progression:
-            self._log_and_return_min_progression(
-                logger=logger,
-                trial_index=None,
-                trial_last_progression=any_last_prog,
-                min_progression=not_none(self.min_progression),
+            logger.info(
+                f"No trials have reached {self.min_progression}. "
+                "Not stopping any trials."
             )
             return False
         return True
@@ -325,6 +323,7 @@ class BaseEarlyStoppingStrategy(ABC, Base):
             1. Check for ignored indices based on `self.trial_indices_to_ignore`
             2. Check that `df` contains data for the trial `trial_index`
             3. Check that the trial has reached `self.min_progression`
+            4. Check that the trial hasn't surpassed `self.max_progression`
         Returns two elements: a boolean indicating if all checks are passed and a
         str indicating the reason that early stopping is not applied (None if all
         checks pass)."""
@@ -342,15 +341,24 @@ class BaseEarlyStoppingStrategy(ABC, Base):
         if df_trial.empty:
             return self._log_and_return_no_data(logger=logger, trial_index=trial_index)
 
-        # check for min progression
+        # check for min/max progression
         trial_last_prog = df_trial[map_key].max()
         logger.info(f"Last progression of Trial {trial_index} is {trial_last_prog}.")
         if self.min_progression is not None and trial_last_prog < self.min_progression:
-            return self._log_and_return_min_progression(
+            return self._log_and_return_progression_range(
                 logger=logger,
                 trial_index=trial_index,
                 trial_last_progression=trial_last_prog,
-                min_progression=not_none(self.min_progression),
+                min_progression=self.min_progression,
+                max_progression=self.max_progression,
+            )
+        if self.max_progression is not None and trial_last_prog > self.max_progression:
+            return self._log_and_return_progression_range(
+                logger=logger,
+                trial_index=trial_index,
+                trial_last_progression=trial_last_prog,
+                min_progression=self.min_progression,
+                max_progression=self.max_progression,
             )
         return True, None
 
@@ -371,6 +379,84 @@ class ModelBasedEarlyStoppingStrategy(BaseEarlyStoppingStrategy):
     """A base class for model based early stopping strategies. Includes
     a helper function for processing MapData into arrays."""
 
+    def __init__(
+        self,
+        metric_names: Optional[Iterable[str]] = None,
+        seconds_between_polls: int = 300,
+        min_progression: Optional[float] = None,
+        max_progression: Optional[float] = None,
+        min_curves: Optional[int] = None,
+        trial_indices_to_ignore: Optional[List[int]] = None,
+        true_objective_metric_name: Optional[str] = None,
+        normalize_progressions: bool = False,
+        min_progression_modeling: Optional[float] = None,
+    ) -> None:
+        """A ModelBasedEarlyStoppingStrategy class.
+
+        Args:
+            metric_names: The names of the metrics the strategy will interact with.
+                If no metric names are provided the objective metric is assumed.
+            seconds_between_polls: How often to poll the early stopping metric to
+                evaluate whether or not the trial should be early stopped.
+            min_progression: Only stop trials if the latest progression value
+                (e.g. timestamp, epochs, training data used) is greater than this
+                threshold. Prevents stopping prematurely before enough data is gathered
+                to make a decision.
+            max_progression: Do not stop trials that have passed `max_progression`.
+                Useful if we prefer finishing a trial that are already near completion.
+            min_curves: There must be `min_curves` number of completed trials and
+                `min_curves` number of trials with curve data to make a stopping
+                decision (i.e., even if there are enough completed trials but not all
+                of them are correctly returning data, then do not apply early stopping).
+            trial_indices_to_ignore: Trial indices that should not be early stopped.
+            true_objective_metric_name: The actual objective to be optimized; used in
+                situations where early stopping uses a proxy objective (such as training
+                loss instead of eval loss) for stopping decisions.
+            normalize_progressions: Normalizes the progression column of the MapData df
+                by dividing by the max. If the values were originally in [0, `prog_max`]
+                (as we would expect), the transformed values will be in [0, 1]. Useful
+                for inferring the max progression and allows `min_progression` to be
+                specified in the transformed space. IMPORTANT: Typically, `min_curves`
+                should be > 0 to ensure that at least one trial has completed and that
+                we have a reliable approximation for `prog_max`.
+            min_progression_modeling: If set, this will exclude progressions that are
+                below this threshold from being used or modeling. Useful when early data
+                is not reliable or excessively noisy.
+        """
+        super().__init__(
+            metric_names=metric_names,
+            seconds_between_polls=seconds_between_polls,
+            min_progression=min_progression,
+            max_progression=max_progression,
+            min_curves=min_curves,
+            trial_indices_to_ignore=trial_indices_to_ignore,
+            true_objective_metric_name=true_objective_metric_name,
+            normalize_progressions=normalize_progressions,
+        )
+        self.min_progression_modeling = min_progression_modeling
+
+    def _check_validity_and_get_data(
+        self, experiment: Experiment, metric_names: List[str]
+    ) -> Optional[MapData]:
+        """Validity checks and returns the `MapData` used for early stopping that
+        is associated with `metric_names`. This function also handles normalizing
+        progressions.
+        """
+        map_data = super()._check_validity_and_get_data(
+            experiment=experiment, metric_names=metric_names
+        )
+        if map_data is not None and self.min_progression_modeling is not None:
+            map_df = map_data.map_df
+            map_df = map_df[
+                map_df[map_data.map_keys[0]] >= self.min_progression_modeling
+            ]
+            map_data = MapData(
+                df=map_df,
+                map_key_infos=map_data.map_key_infos,
+                description=map_data.description,
+            )
+        return map_data
+
     def get_training_data(
         self,
         experiment: Experiment,
@@ -400,7 +486,6 @@ class ModelBasedEarlyStoppingStrategy(BaseEarlyStoppingStrategy):
                 map_key=map_data.map_keys[0],
                 limit_total_rows=max_training_size,
             )
-
         if outcomes is None:
             # default to the default objective
             metric_name, _ = self._default_objective_and_direction(
@@ -448,7 +533,7 @@ def get_transform_helper_model(
     Returns: A torch modelbridge.
     """
     if transforms is None:
-        transforms = Cont_X_trans + Y_trans
+        transforms = Cont_X_trans + [MapUnitX] + Y_trans
     return MapTorchModelBridge(
         experiment=experiment,
         search_space=experiment.search_space,
