@@ -1,10 +1,10 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
-from typing import Any
+from typing import Any, Iterable
 
 
 class DataProviderError(Exception):
@@ -16,7 +16,11 @@ class DataProviderError(Exception):
     """
 
     def __init__(
-        self, message: str, data_provider: str, data_provider_error: Any
+        self,
+        message: str,
+        data_provider: str,
+        # pyre-fixme[2]: Parameter annotation cannot be `Any`.
+        data_provider_error: Any,
     ) -> None:
         self.message = message
         self.data_provider = data_provider
@@ -31,3 +35,16 @@ class DataProviderError(Exception):
             message=self.message,
             dp_error=self.data_provider_error,
         )
+
+
+class MissingDataError(Exception):
+    def __init__(self, missing_trial_indexes: Iterable[int]) -> None:
+        missing_trial_str = ", ".join([str(index) for index in missing_trial_indexes])
+        self.message: str = (
+            f"Unable to find data for the following trials: {missing_trial_str} "
+            "consider updating the data fetching kwargs or manually fetching "
+            "data via `refetch_data()`"
+        )
+
+    def __str__(self) -> str:
+        return self.message
