@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -32,3 +32,11 @@ class GenerationStrategyCompleted(OptimizationComplete):
     """
 
     pass
+
+
+class GenerationStrategyRepeatedPoints(GenerationStrategyCompleted):
+    """Special exception indicating that the generation strategy is repeatedly
+    suggesting previously sampled points.
+    """
+
+    pass
