@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -11,14 +11,11 @@ import torch
 from ax.core.data import Data
 from ax.core.experiment import Experiment
 from ax.core.multi_type_experiment import MultiTypeExperiment
-from ax.core.objective import MultiObjective
 from ax.core.observation import ObservationFeatures
-from ax.core.optimization_config import OptimizationConfig, TRefPoint
-from ax.core.outcome_constraint import ObjectiveThreshold
+from ax.core.optimization_config import OptimizationConfig
 from ax.core.search_space import SearchSpace
-from ax.core.types import TConfig
 from ax.modelbridge.discrete import DiscreteModelBridge
-from ax.modelbridge.multi_objective_torch import MultiObjectiveTorchModelBridge
+from ax.modelbridge.modelbridge_utils import check_has_multi_objective_and_data
 from ax.modelbridge.random import RandomModelBridge
 from ax.modelbridge.registry import (
     Cont_X_trans,
@@ -37,15 +34,10 @@ from ax.models.torch.botorch import (
     TModelPredictor,
     TOptimizer,
 )
-from ax.models.torch.botorch_defaults import (
-    get_and_fit_model,
-    get_NEI,
-    predict_from_model,
-    scipy_optimizer,
-)
-from ax.models.torch.botorch_moo_defaults import (
-    get_EHVI,
-)
+from ax.models.torch.botorch_defaults import get_and_fit_model, get_NEI, scipy_optimizer
+from ax.models.torch.botorch_moo_defaults import get_EHVI
+from ax.models.torch.utils import predict_from_model
+from ax.models.types import TConfig
 from ax.utils.common.logger import get_logger
 from ax.utils.common.typeutils import checked_cast
 
@@ -72,27 +64,25 @@ optimization model for subsequent trials).
 def get_MOO_NEHVI(
     experiment: Experiment,
     data: Data,
-    objective_thresholds: Optional[TRefPoint] = None,
     search_space: Optional[SearchSpace] = None,
     dtype: torch.dtype = torch.double,
-    device: torch.device = (
-        torch.device("cuda") if torch.cuda.is_available() else torch.device("cpu")
-    ),
+    device: Optional[torch.device] = None,
     status_quo_features: Optional[ObservationFeatures] = None,
     use_input_warping: bool = False,
-) -> MultiObjectiveTorchModelBridge:
+    optimization_config: Optional[OptimizationConfig] = None,
+) -> TorchModelBridge:
     """Instantiates a multi-objective model using qNEHVI."""
-    # pyre-ignore: [16] `Optional` has no attribute `objective`.
-    if not isinstance(experiment.optimization_config.objective, MultiObjective):
-        raise ValueError("Multi-objective optimization requires multiple objectives.")
-    if data.df.empty:  # pragma: no cover
-        raise ValueError("MultiObjectiveOptimization requires non-empty data.")
+    device = device or (
+        torch.device("cuda") if torch.cuda.is_available() else torch.device("cpu")
+    )
+    check_has_multi_objective_and_data(
+        experiment=experiment, data=data, optimization_config=optimization_config
+    )
     return checked_cast(
-        MultiObjectiveTorchModelBridge,
+        TorchModelBridge,
         Models.MOO(
             experiment=experiment,
             data=data,
-            objective_thresholds=objective_thresholds,
             search_space=search_space or experiment.search_space,
             torch_dtype=dtype,
             torch_device=device,
@@ -106,6 +96,7 @@ def get_MOO_NEHVI(
                 },
             },
             use_input_warping=use_input_warping,
+            optimization_config=optimization_config,
         ),
     )
 
@@ -113,11 +104,11 @@ def get_MOO_NEHVI(
 def get_MTGP_NEHVI(
     experiment: Experiment,
     data: Data,
-    objective_thresholds: Optional[List[ObjectiveThreshold]] = None,
     search_space: Optional[SearchSpace] = None,
     dtype: torch.dtype = torch.double,
-    device: torch.device = DEFAULT_TORCH_DEVICE,
+    device: Optional[torch.device] = None,
     trial_index: Optional[int] = None,
+    optimization_config: Optional[OptimizationConfig] = None,
 ) -> TorchModelBridge:
     """Instantiates a Multi-task Gaussian Process (MTGP) model that generates
     points with qNEHVI.
@@ -126,11 +117,12 @@ def get_MTGP_NEHVI(
     Multi-type Multi-task GP model will be instantiated.
     Otherwise, the model will be a Single-type Multi-task GP.
     """
-    # pyre-ignore: [16] `Optional` has no attribute `objective`.
-    if not isinstance(experiment.optimization_config.objective, MultiObjective):
-        raise ValueError("Multi-objective optimization requires multiple objectives.")
-    elif data.df.empty:  # pragma: no cover
-        raise ValueError("MultiObjectiveOptimization requires non-empty data.")
+    device = device or (
+        torch.device("cuda") if torch.cuda.is_available() else torch.device("cpu")
+    )
+    check_has_multi_objective_and_data(
+        experiment=experiment, data=data, optimization_config=optimization_config
+    )
 
     if isinstance(experiment, MultiTypeExperiment):
         trial_index_to_type = {
@@ -160,15 +152,17 @@ def get_MTGP_NEHVI(
         status_quo_features = None
     else:
         status_quo_features = ObservationFeatures(
-            parameters=status_quo.parameters, trial_index=trial_index
+            parameters=status_quo.parameters,
+            # pyre-fixme[6]: Expected `Optional[numpy.int64]` for 2nd param but got
+            #  `int`.
+            trial_index=trial_index,
         )
 
     return checked_cast(
-        MultiObjectiveTorchModelBridge,
+        TorchModelBridge,
         Models.MOO(
             experiment=experiment,
             data=data,
-            objective_thresholds=objective_thresholds,
             search_space=search_space or experiment.search_space,
             transforms=transforms,
             transform_configs=transform_configs,
@@ -183,6 +177,7 @@ def get_MTGP_NEHVI(
                     "sequential": True,
                 },
             },
+            optimization_config=optimization_config,
         ),
     )
 
@@ -193,6 +188,7 @@ def get_sobol(
     deduplicate: bool = False,
     init_position: int = 0,
     scramble: bool = True,
+    fallback_to_sample_polytope: bool = False,
 ) -> RandomModelBridge:
     """Instantiates a Sobol sequence quasi-random generator.
 
@@ -211,6 +207,7 @@ def get_sobol(
             deduplicate=deduplicate,
             init_position=init_position,
             scramble=scramble,
+            fallback_to_sample_polytope=fallback_to_sample_polytope,
         ),
     )
 
@@ -337,6 +334,8 @@ def get_MTGP(
     data: Data,
     search_space: Optional[SearchSpace] = None,
     trial_index: Optional[int] = None,
+    device: torch.device = DEFAULT_TORCH_DEVICE,
+    dtype: torch.dtype = torch.double,
 ) -> TorchModelBridge:
     """Instantiates a Multi-task Gaussian Process (MTGP) model that generates
     points with EI.
@@ -374,7 +373,10 @@ def get_MTGP(
         status_quo_features = None
     else:
         status_quo_features = ObservationFeatures(
-            parameters=status_quo.parameters, trial_index=trial_index
+            parameters=status_quo.parameters,
+            # pyre-fixme[6]: Expected `Optional[numpy.int64]` for 2nd param but got
+            #  `int`.
+            trial_index=trial_index,
         )
 
     return TorchModelBridge(
@@ -390,8 +392,8 @@ def get_MTGP(
         #  typing.Union[botorch.acquisition.acquisition.AcquisitionFunction, float,
         #  int, str]]]]]`.
         transform_configs=transform_configs,
-        torch_dtype=torch.double,
-        torch_device=DEFAULT_TORCH_DEVICE,
+        torch_dtype=dtype,
+        torch_device=device,
         status_quo_features=status_quo_features,
     )
 
@@ -490,35 +492,31 @@ def get_GPMES(
 def get_MOO_EHVI(
     experiment: Experiment,
     data: Data,
-    objective_thresholds: Optional[TRefPoint] = None,
     search_space: Optional[SearchSpace] = None,
     dtype: torch.dtype = torch.double,
     device: Optional[torch.device] = None,
-) -> MultiObjectiveTorchModelBridge:
+    optimization_config: Optional[OptimizationConfig] = None,
+) -> TorchModelBridge:
     """Instantiates a multi-objective model that generates points with EHVI.
 
-    Requires `objective_thresholds`,
-    a list of `ax.core.ObjectiveThresholds`, for every objective being optimized.
-    An arm only improves hypervolume if it is strictly better than all
-    objective thresholds.
+    Requires `objective_thresholds`, a list of `ax.core.ObjectiveThresholds`,
+    for every objective being optimized. An arm only improves hypervolume if
+    it is strictly better than all objective thresholds.
 
-    `objective_thresholds` can be passed in the optimization_config or
-    passed directly here.
+    `objective_thresholds` should be included in the `optimization_config` or
+    `experiment.optimization_config`.
     """
     device = device or (
         torch.device("cuda") if torch.cuda.is_available() else torch.device("cpu")
     )
-    # pyre-ignore: [16] `Optional` has no attribute `objective`.
-    if not isinstance(experiment.optimization_config.objective, MultiObjective):
-        raise ValueError("Multi-objective optimization requires multiple objectives.")
-    if data.df.empty:  # pragma: no cover
-        raise ValueError("MultiObjectiveOptimization requires non-empty data.")
+    check_has_multi_objective_and_data(
+        experiment=experiment, data=data, optimization_config=optimization_config
+    )
     return checked_cast(
-        MultiObjectiveTorchModelBridge,
+        TorchModelBridge,
         Models.MOO(
             experiment=experiment,
             data=data,
-            objective_thresholds=objective_thresholds,
             search_space=search_space or experiment.search_space,
             torch_dtype=dtype,
             torch_device=device,
@@ -531,6 +529,7 @@ def get_MOO_EHVI(
                     "batch_limit": DEFAULT_EHVI_BATCH_LIMIT
                 },
             },
+            optimization_config=optimization_config,
         ),
     )
 
@@ -538,27 +537,24 @@ def get_MOO_EHVI(
 def get_MOO_PAREGO(
     experiment: Experiment,
     data: Data,
-    objective_thresholds: Optional[TRefPoint] = None,
     search_space: Optional[SearchSpace] = None,
     dtype: torch.dtype = torch.double,
     device: torch.device = DEFAULT_TORCH_DEVICE,
-) -> MultiObjectiveTorchModelBridge:
+    optimization_config: Optional[OptimizationConfig] = None,
+) -> TorchModelBridge:
     """Instantiates a multi-objective model that generates points with ParEGO.
 
     qParEGO optimizes random augmented chebyshev scalarizations of the multiple
     objectives. This allows it to explore non-convex pareto frontiers.
     """
-    # pyre-ignore: [16] `Optional` has no attribute `objective`.
-    if not isinstance(experiment.optimization_config.objective, MultiObjective):
-        raise ValueError("Multi-Objective optimization requires multiple objectives")
-    if data.df.empty:
-        raise ValueError("MultiObjectiveOptimization requires non-empty data.")
+    check_has_multi_objective_and_data(
+        experiment=experiment, data=data, optimization_config=optimization_config
+    )
     return checked_cast(
-        MultiObjectiveTorchModelBridge,
+        TorchModelBridge,
         Models.MOO(
             experiment=experiment,
             data=data,
-            objective_thresholds=objective_thresholds,
             search_space=search_space or experiment.search_space,
             torch_dtype=dtype,
             torch_device=device,
@@ -569,6 +565,7 @@ def get_MOO_PAREGO(
                     "sequential": True,
                 }
             },
+            optimization_config=optimization_config,
         ),
     )
 
@@ -576,28 +573,25 @@ def get_MOO_PAREGO(
 def get_MOO_RS(
     experiment: Experiment,
     data: Data,
-    objective_thresholds: Optional[TRefPoint] = None,
     search_space: Optional[SearchSpace] = None,
     dtype: torch.dtype = torch.double,
     device: torch.device = DEFAULT_TORCH_DEVICE,
-) -> MultiObjectiveTorchModelBridge:
+    optimization_config: Optional[OptimizationConfig] = None,
+) -> TorchModelBridge:
     """Instantiates a Random Scalarization multi-objective model.
 
     Chooses a different random linear scalarization of the objectives
     for generating each new candidate arm. This will only explore the
     convex hull of the pareto frontier.
     """
-    # pyre-ignore: [16] `Optional` has no attribute `objective`.
-    if not isinstance(experiment.optimization_config.objective, MultiObjective):
-        raise ValueError("Multi-Objective optimization requires multiple objectives")
-    if data.df.empty:
-        raise ValueError("MultiObjectiveOptimization requires non-empty data.")
+    check_has_multi_objective_and_data(
+        experiment=experiment, data=data, optimization_config=optimization_config
+    )
     return checked_cast(
-        MultiObjectiveTorchModelBridge,
+        TorchModelBridge,
         Models.MOO(
             experiment=experiment,
             data=data,
-            objective_thresholds=objective_thresholds,
             search_space=search_space or experiment.search_space,
             torch_dtype=dtype,
             torch_device=device,
@@ -608,6 +602,7 @@ def get_MOO_RS(
                     "sequential": True,
                 }
             },
+            optimization_config=optimization_config,
         ),
     )
 
@@ -616,21 +611,19 @@ def get_MTGP_PAREGO(
     experiment: Experiment,
     data: Data,
     trial_index: Optional[int] = None,
-    objective_thresholds: Optional[TRefPoint] = None,
     search_space: Optional[SearchSpace] = None,
     dtype: torch.dtype = torch.double,
     device: torch.device = DEFAULT_TORCH_DEVICE,
-) -> MultiObjectiveTorchModelBridge:
+    optimization_config: Optional[OptimizationConfig] = None,
+) -> TorchModelBridge:
     """Instantiates a multi-objective, multi-task model that uses qParEGO.
 
     qParEGO optimizes random augmented chebyshev scalarizations of the multiple
     objectives. This allows it to explore non-convex pareto frontiers.
     """
-    # pyre-ignore: [16] `Optional` has no attribute `objective`.
-    if not isinstance(experiment.optimization_config.objective, MultiObjective):
-        raise ValueError("Multi-objective optimization requires multiple objectives.")
-    elif data.df.empty:  # pragma: no cover
-        raise ValueError("MultiObjectiveOptimization requires non-empty data.")
+    check_has_multi_objective_and_data(
+        experiment=experiment, data=data, optimization_config=optimization_config
+    )
 
     if isinstance(experiment, MultiTypeExperiment):
         trial_index_to_type = {
@@ -660,14 +653,16 @@ def get_MTGP_PAREGO(
         status_quo_features = None
     else:
         status_quo_features = ObservationFeatures(
-            parameters=status_quo.parameters, trial_index=trial_index
+            parameters=status_quo.parameters,
+            # pyre-fixme[6]: Expected `Optional[numpy.int64]` for 2nd param but got
+            #  `int`.
+            trial_index=trial_index,
         )
     return checked_cast(
-        MultiObjectiveTorchModelBridge,
+        TorchModelBridge,
         Models.MOO(
             experiment=experiment,
             data=data,
-            objective_thresholds=objective_thresholds,
             search_space=search_space or experiment.search_space,
             torch_dtype=dtype,
             torch_device=device,
@@ -681,5 +676,6 @@ def get_MTGP_PAREGO(
                     "sequential": True,
                 }
             },
+            optimization_config=optimization_config,
         ),
     )
