@@ -32,6 +32,7 @@ from ax.core.base_trial import TrialStatus
 from ax.core.batch_trial import BatchTrial
 from ax.core.data import Data
 from ax.core.experiment import Experiment
+from ax.core.generator_run import GeneratorRun
 from ax.core.objective import MultiObjective, Objective, ScalarizedObjective
 from ax.core.observation import Observation, ObservationData, ObservationFeatures
 from ax.core.optimization_config import (
@@ -57,13 +58,16 @@ from ax.core.trial import Trial
 from ax.core.types import TBounds, TCandidateMetadata
 from ax.exceptions.core import UnsupportedError, UserInputError
 from ax.modelbridge.transforms.base import Transform
-from ax.modelbridge.transforms.derelativize import Derelativize
+from ax.modelbridge.transforms.utils import (
+    derelativize_optimization_config_with_raw_status_quo,
+)
 from ax.models.torch.botorch_moo_defaults import pareto_frontier_evaluator
 from ax.models.torch.frontier_utils import (
     get_weighted_mc_objective_and_objective_thresholds,
 )
 from ax.utils.common.logger import get_logger
 from ax.utils.common.typeutils import (
+    checked_cast,
     checked_cast_optional,
     checked_cast_to_tuple,
     not_none,
@@ -763,6 +767,22 @@ def get_pending_observation_features_based_on_trial_status(
     return dict(pending_features) if any(x for x in pending_features.values()) else None
 
 
+def extend_pending_observations(
+    experiment: Experiment,
+    pending_observations: Dict[str, List[ObservationFeatures]],
+    generator_run: GeneratorRun,
+) -> None:
+    """Extend given pending observations dict (from metric name to observations
+    that are pending for that metric), with arms in a given generator run.
+    """
+    for m in experiment.metrics:
+        if m not in pending_observations:
+            pending_observations[m] = []
+        pending_observations[m].extend(
+            ObservationFeatures.from_arm(a) for a in generator_run.arms
+        )
+
+
 def get_pareto_frontier_and_configs(
     modelbridge: modelbridge_module.torch.TorchModelBridge,
     observation_features: List[ObservationFeatures],
@@ -866,20 +886,17 @@ def get_pareto_frontier_and_configs(
     )
 
     # Transform optimization config.
-    fixed_features = ObservationFeatures(parameters={})
 
     # de-relativize outcome constraints and objective thresholds
     observations = modelbridge.get_training_data()
-    tf = Derelativize(
-        search_space=modelbridge.model_space.clone(),
-        observations=observations,
-        config={"use_raw_status_quo": True},
-    )
-    # pyre-ignore [9]
-    optimization_config = tf.transform_optimization_config(
-        optimization_config=optimization_config.clone(),
-        modelbridge=modelbridge,
-        fixed_features=fixed_features,
+
+    optimization_config = checked_cast(
+        MultiObjectiveOptimizationConfig,
+        derelativize_optimization_config_with_raw_status_quo(
+            optimization_config=optimization_config,
+            modelbridge=modelbridge,
+            observations=observations,
+        ),
     )
     # Extract weights, constraints, and objective_thresholds
     objective_weights = extract_objective_weights(
