@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -10,16 +10,17 @@ from math import sqrt
 import numpy as np
 from ax.core.metric import Metric
 from ax.core.objective import Objective
-from ax.core.observation import ObservationData
+from ax.core.observation import Observation, ObservationData, ObservationFeatures
 from ax.core.optimization_config import OptimizationConfig
 from ax.core.outcome_constraint import OutcomeConstraint, ScalarizedOutcomeConstraint
 from ax.core.types import ComparisonOp
+from ax.exceptions.core import DataRequiredError
 from ax.modelbridge.transforms.standardize_y import StandardizeY
 from ax.utils.common.testutils import TestCase
 
 
 class StandardizeYTransformTest(TestCase):
-    def setUp(self):
+    def setUp(self) -> None:
         self.obsd1 = ObservationData(
             metric_names=["m1", "m2", "m2"],
             means=np.array([1.0, 2.0, 1.0]),
@@ -37,21 +38,23 @@ class StandardizeYTransformTest(TestCase):
                 ]
             ),
         )
+        obs1 = Observation(features=ObservationFeatures({}), data=self.obsd1)
+        obs2 = Observation(features=ObservationFeatures({}), data=self.obsd2)
         self.t = StandardizeY(
             search_space=None,
-            observation_features=None,
-            observation_data=[self.obsd1, self.obsd2],
+            observations=[obs1, obs2],
         )
 
-    def testInit(self):
+    def testInit(self) -> None:
         self.assertEqual(self.t.Ymean, {"m1": 1.0, "m2": 1.5})
         self.assertEqual(self.t.Ystd, {"m1": 1.0, "m2": sqrt(1 / 3)})
-        with self.assertRaises(ValueError):
+        with self.assertRaises(DataRequiredError):
             StandardizeY(
-                search_space=None, observation_features=None, observation_data=[]
+                search_space=None,
+                observations=[],
             )
 
-    def testTransformObservations(self):
+    def testTransformObservations(self) -> None:
         obsd1_t = ObservationData(
             metric_names=["m1", "m2", "m2"],
             means=np.array([0.0, sqrt(3 / 4), -sqrt(3 / 4)]),
@@ -64,12 +67,12 @@ class StandardizeYTransformTest(TestCase):
             ),
         )
         obsd2 = [deepcopy(self.obsd1)]
-        obsd2 = self.t.transform_observation_data(obsd2, [])
+        obsd2 = self.t._transform_observation_data(obsd2)
         self.assertTrue(osd_allclose(obsd2[0], obsd1_t))
-        obsd2 = self.t.untransform_observation_data(obsd2, [])
+        obsd2 = self.t._untransform_observation_data(obsd2)
         self.assertTrue(osd_allclose(obsd2[0], self.obsd1))
 
-    def testTransformOptimizationConfig(self):
+    def testTransformOptimizationConfig(self) -> None:
         m1 = Metric(name="m1")
         m2 = Metric(name="m2")
         m3 = Metric(name="m3")
