@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -10,7 +10,7 @@ from math import sqrt
 import numpy as np
 from ax.core.metric import Metric
 from ax.core.objective import Objective
-from ax.core.observation import ObservationData, ObservationFeatures
+from ax.core.observation import Observation, ObservationData, ObservationFeatures
 from ax.core.optimization_config import OptimizationConfig
 from ax.core.outcome_constraint import OutcomeConstraint
 from ax.core.parameter import ChoiceParameter, ParameterType, RangeParameter
@@ -23,7 +23,7 @@ from .test_standardize_y_transform import osd_allclose
 
 
 class StratifiedStandardizeYTransformTest(TestCase):
-    def setUp(self):
+    def setUp(self) -> None:
         self.obsd1 = ObservationData(
             metric_names=["m1", "m2", "m2"],
             means=np.array([1.0, 2.0, 8.0]),
@@ -53,14 +53,15 @@ class StratifiedStandardizeYTransformTest(TestCase):
         )
         self.obsf1 = ObservationFeatures({"x": 2, "z": "a"})
         self.obsf2 = ObservationFeatures({"x": 5, "z": "b"})
+        self.obs1 = Observation(features=self.obsf1, data=self.obsd1)
+        self.obs2 = Observation(features=self.obsf2, data=self.obsd2)
         self.t = StratifiedStandardizeY(
             search_space=self.search_space,
-            observation_features=[self.obsf1, self.obsf2],
-            observation_data=[self.obsd1, self.obsd2],
+            observations=[self.obs1, self.obs2],
             config={"parameter_name": "z"},
         )
 
-    def testInit(self):
+    def testInit(self) -> None:
         Ymean_expected = {
             ("m1", "a"): 1.0,
             ("m1", "b"): 3.0,
@@ -84,15 +85,13 @@ class StratifiedStandardizeYTransformTest(TestCase):
             # No parameter specified
             StratifiedStandardizeY(
                 search_space=self.search_space,
-                observation_features=[self.obsf1, self.obsf2],
-                observation_data=[self.obsd1, self.obsd2],
+                observations=[self.obs1, self.obs2],
             )
         with self.assertRaises(ValueError):
             # Wrong parameter type
             StratifiedStandardizeY(
                 search_space=self.search_space,
-                observation_features=[self.obsf1, self.obsf2],
-                observation_data=[self.obsd1, self.obsd2],
+                observations=[self.obs1, self.obs2],
                 config={"parameter_name": "x"},
             )
         # Multiple tasks parameters
@@ -118,8 +117,7 @@ class StratifiedStandardizeYTransformTest(TestCase):
         with self.assertRaises(ValueError):
             StratifiedStandardizeY(
                 search_space=ss3,
-                observation_features=[self.obsf1, self.obsf2],
-                observation_data=[self.obsd1, self.obsd2],
+                observations=[self.obs1, self.obs2],
             )
 
         # Grab from task feature
@@ -138,8 +136,7 @@ class StratifiedStandardizeYTransformTest(TestCase):
         )
         t2 = StratifiedStandardizeY(
             search_space=ss2,
-            observation_features=[self.obsf1, self.obsf2],
-            observation_data=[self.obsd1, self.obsd2],
+            observations=[self.obs1, self.obs2],
         )
         self.assertEqual(
             t2.Ymean,
@@ -149,7 +146,7 @@ class StratifiedStandardizeYTransformTest(TestCase):
         for k, v in t2.Ystd.items():
             self.assertAlmostEqual(v, Ystd_expected[k])
 
-    def testTransformObservations(self):
+    def testTransformObservations(self) -> None:
         std_m2_a = sqrt(2) * 3
         obsd1_ta = ObservationData(
             metric_names=["m1", "m2", "m2"],
@@ -174,26 +171,26 @@ class StratifiedStandardizeYTransformTest(TestCase):
                 ]
             ),
         )
-        obsd2 = [deepcopy(self.obsd1)]
-        obsd2 = self.t.transform_observation_data(
-            obsd2, [ObservationFeatures({"z": "a"})]
-        )
-        self.assertTrue(osd_allclose(obsd2[0], obsd1_ta))
-        obsd2 = self.t.untransform_observation_data(
-            obsd2, [ObservationFeatures({"z": "a"})]
-        )
-        self.assertTrue(osd_allclose(obsd2[0], self.obsd1))
-        obsd2 = [deepcopy(self.obsd1)]
-        obsd2 = self.t.transform_observation_data(
-            obsd2, [ObservationFeatures({"z": "b"})]
-        )
-        self.assertTrue(osd_allclose(obsd2[0], obsd1_tb))
-        obsd2 = self.t.untransform_observation_data(
-            obsd2, [ObservationFeatures({"z": "b"})]
-        )
-        self.assertTrue(osd_allclose(obsd2[0], self.obsd1))
+        obsd2 = deepcopy(self.obsd1)
+        obsd2 = self.t.transform_observations(
+            [Observation(data=obsd2, features=ObservationFeatures({"z": "a"}))]
+        )[0].data
+        self.assertTrue(osd_allclose(obsd2, obsd1_ta))
+        obsd2 = self.t.untransform_observations(
+            [Observation(data=obsd2, features=ObservationFeatures({"z": "a"}))]
+        )[0].data
+        self.assertTrue(osd_allclose(obsd2, self.obsd1))
+        obsd2 = deepcopy(self.obsd1)
+        obsd2 = self.t.transform_observations(
+            [Observation(data=obsd2, features=ObservationFeatures({"z": "b"}))]
+        )[0].data
+        self.assertTrue(osd_allclose(obsd2, obsd1_tb))
+        obsd2 = self.t.untransform_observations(
+            [Observation(data=obsd2, features=ObservationFeatures({"z": "b"}))]
+        )[0].data
+        self.assertTrue(osd_allclose(obsd2, self.obsd1))
 
-    def testTransformOptimizationConfig(self):
+    def testTransformOptimizationConfig(self) -> None:
         m1 = Metric(name="m1")
         m2 = Metric(name="m2")
         m3 = Metric(name="m3")
