@@ -1,18 +1,18 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
+from logging import Logger
 from typing import Dict, List
 
 import numpy as np
-from ax.core.observation import ObservationData, ObservationFeatures
+from ax.core.observation import ObservationData
 from ax.modelbridge.transforms.base import Transform
 from ax.utils.common.logger import get_logger
 
-
-logger = get_logger(__name__)
+logger: Logger = get_logger(__name__)
 
 
 def ivw_metric_merge(
@@ -110,10 +110,9 @@ class IVW(Transform):
     are combined using inverse variance weighting.
     """
 
-    def transform_observation_data(
+    def _transform_observation_data(
         self,
         observation_data: List[ObservationData],
-        observation_features: List[ObservationFeatures],
     ) -> List[ObservationData]:
         # pyre: conflicting_noiseless is declared to have type `str` but is
         # pyre-fixme[9]: used as type `typing.Union[float, int, str]`.
