@@ -1,17 +1,22 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
-from typing import TYPE_CHECKING, Callable, List, Optional, Tuple
+from __future__ import annotations
+
+from logging import Logger
+
+from typing import Callable, List, Optional, Tuple, TYPE_CHECKING
 
 import numpy as np
-from ax.core.observation import ObservationData, ObservationFeatures
+from ax.core.observation import Observation, ObservationData, ObservationFeatures
 from ax.core.optimization_config import OptimizationConfig
+from ax.core.outcome_constraint import OutcomeConstraint
 from ax.core.search_space import SearchSpace
-from ax.core.types import TConfig
 from ax.modelbridge.transforms.base import Transform
+from ax.models.types import TConfig
 from ax.utils.common.logger import get_logger
 from scipy.stats import norm
 
@@ -21,7 +26,7 @@ if TYPE_CHECKING:
     from ax.modelbridge import base as base_modelbridge  # noqa F401  # pragma: no cover
 
 
-logger = get_logger(__name__)
+logger: Logger = get_logger(__name__)
 
 
 class LogY(Transform):
@@ -38,9 +43,9 @@ class LogY(Transform):
 
     def __init__(
         self,
-        search_space: SearchSpace,
-        observation_features: List[ObservationFeatures],
-        observation_data: List[ObservationData],
+        search_space: Optional[SearchSpace] = None,
+        observations: Optional[List[Observation]] = None,
+        modelbridge: Optional["base_modelbridge.ModelBridge"] = None,
         config: Optional[TConfig] = None,
     ) -> None:
         if config is None:
@@ -53,15 +58,17 @@ class LogY(Transform):
             raise ValueError("Must specify at least one metric in the config.")
         super().__init__(
             search_space=search_space,
-            observation_features=observation_features,
-            observation_data=observation_data,
+            observations=observations,
             config=config,
         )
+        # pyre-fixme[4]: Attribute must be annotated.
         self.metric_names = metric_names
         if config.get("match_ci_width", False):
             # perform moment-matching to compute variance that results in a CI
             # of same width as the when transforming the moments
+            # pyre-fixme[4]: Attribute must be annotated.
             self._transform = lambda m, v: match_ci_width(m, v, np.log)
+            # pyre-fixme[4]: Attribute must be annotated.
             self._untransform = lambda m, v: match_ci_width(m, v, np.exp)
         else:
             self._transform = lognorm_to_norm
@@ -70,21 +77,27 @@ class LogY(Transform):
     def transform_optimization_config(
         self,
         optimization_config: OptimizationConfig,
-        modelbridge: Optional["base_modelbridge.ModelBridge"],
-        fixed_features: ObservationFeatures,
+        modelbridge: Optional[base_modelbridge.ModelBridge] = None,
+        fixed_features: Optional[ObservationFeatures] = None,
     ) -> OptimizationConfig:
         for c in optimization_config.all_constraints:
             if c.metric.name in self.metric_names:
-                raise ValueError(
-                    f"LogY transform cannot be applied to metric {c.metric.name} "
-                    " since it is subject to an outcome constraint"
-                )
+                base_str = f"LogY transform cannot be applied to metric {c.metric.name}"
+                if c.relative:
+                    raise ValueError(
+                        f"{base_str} since it is subject to a relative constraint."
+                    )
+                elif c.bound <= 0:
+                    raise ValueError(
+                        f"{base_str} since the bound isn't positive, got: {c.bound}."
+                    )
+                else:
+                    c.bound = np.log(c.bound)
         return optimization_config
 
     def _tf_obs_data(
         self,
         observation_data: List[ObservationData],
-        observation_features: List[ObservationFeatures],
         transform: Callable[[np.ndarray, np.ndarray], Tuple[np.ndarray, np.ndarray]],
     ) -> List[ObservationData]:
         for obsd in observation_data:
@@ -114,23 +127,31 @@ class LogY(Transform):
                 obsd.covariance = cov
         return observation_data
 
-    def transform_observation_data(
+    def _transform_observation_data(
         self,
         observation_data: List[ObservationData],
-        observation_features: List[ObservationFeatures],
     ) -> List[ObservationData]:
-        return self._tf_obs_data(
-            observation_data, observation_features, self._transform
-        )
+        return self._tf_obs_data(observation_data, self._transform)
 
-    def untransform_observation_data(
+    def _untransform_observation_data(
         self,
         observation_data: List[ObservationData],
-        observation_features: List[ObservationFeatures],
     ) -> List[ObservationData]:
-        return self._tf_obs_data(
-            observation_data, observation_features, self._untransform
-        )
+        return self._tf_obs_data(observation_data, self._untransform)
+
+    def untransform_outcome_constraints(
+        self,
+        outcome_constraints: List[OutcomeConstraint],
+        fixed_features: Optional[ObservationFeatures] = None,
+    ) -> List[OutcomeConstraint]:
+        for c in outcome_constraints:  # pragma: no cover
+            if c.metric.name in self.metric_names:  # pragma: no cover
+                if c.relative:  # pragma: no cover
+                    raise ValueError(  # pragma: no cover
+                        "Unexpected relative transform."
+                    )
+                c.bound = np.exp(c.bound)  # pragma: no cover
+        return outcome_constraints  # pragma: no cover
 
 
 def match_ci_width(
