@@ -1,16 +1,21 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
-from typing import Dict, List, Optional, Union
+from typing import Dict, List, Optional, TYPE_CHECKING, Union
 
-from ax.core.observation import ObservationData, ObservationFeatures
+from ax.core.observation import Observation, ObservationFeatures
 from ax.core.parameter import ChoiceParameter, FixedParameter, RangeParameter
 from ax.core.search_space import SearchSpace
-from ax.core.types import TConfig
 from ax.modelbridge.transforms.base import Transform
+from ax.modelbridge.transforms.utils import construct_new_search_space
+from ax.models.types import TConfig
+
+if TYPE_CHECKING:
+    # import as module to make sphinx-autodoc-typehints happy
+    from ax import modelbridge as modelbridge_module  # noqa F401  # pragma: no cover
 
 
 class RemoveFixed(Transform):
@@ -19,16 +24,17 @@ class RemoveFixed(Transform):
     Fixed parameters should not be included in the SearchSpace.
     This transform removes these parameters, leaving only tunable parameters.
 
-    Transform is done in-place.
+    Transform is done in-place for observation features.
     """
 
     def __init__(
         self,
-        search_space: SearchSpace,
-        observation_features: List[ObservationFeatures],
-        observation_data: List[ObservationData],
+        search_space: Optional[SearchSpace] = None,
+        observations: Optional[List[Observation]] = None,
+        modelbridge: Optional["modelbridge_module.base.ModelBridge"] = None,
         config: Optional[TConfig] = None,
     ) -> None:
+        assert search_space is not None, "RemoveFixed requires search space"
         # Identify parameters that should be transformed
         self.fixed_parameters: Dict[str, FixedParameter] = {
             p_name: p
@@ -50,7 +56,7 @@ class RemoveFixed(Transform):
                     obsf.parameters.pop(p_name)
         return observation_features
 
-    def transform_search_space(self, search_space: SearchSpace) -> SearchSpace:
+    def _transform_search_space(self, search_space: SearchSpace) -> SearchSpace:
         tunable_parameters: List[Union[ChoiceParameter, RangeParameter]] = []
         for p in search_space.parameters.values():
             if p.name not in self.fixed_parameters:
@@ -60,11 +66,9 @@ class RemoveFixed(Transform):
                 # pyre-fixme[9]: parameter.Parameter`.
                 p_: Union[ChoiceParameter, RangeParameter] = p
                 tunable_parameters.append(p_)
-        return SearchSpace(
-            # Expected `List[ax.core.parameter.Parameter]` for 2nd parameter
-            # `parameters` to call `ax.core.search_space.SearchSpace.__init__`
-            # but got `List[Union[ChoiceParameter, RangeParameter]]`.
-            # pyre-fixme[6]:
+        return construct_new_search_space(
+            search_space=search_space,
+            # pyre-ignore Incompatible parameter type [6]
             parameters=tunable_parameters,
             parameter_constraints=[
                 pc.clone() for pc in search_space.parameter_constraints
