@@ -1,16 +1,22 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
-from typing import Dict, List, Optional
+from typing import Dict, List, Optional, TYPE_CHECKING
 
-from ax.core.observation import ObservationData, ObservationFeatures
+from ax.core.observation import Observation
 from ax.core.parameter import ChoiceParameter, Parameter, ParameterType
 from ax.core.search_space import SearchSpace
-from ax.core.types import TConfig, TParamValue
+from ax.core.types import TParamValue
 from ax.modelbridge.transforms.choice_encode import OrderedChoiceEncode
+from ax.modelbridge.transforms.utils import construct_new_search_space
+from ax.models.types import TConfig
+
+if TYPE_CHECKING:
+    # import as module to make sphinx-autodoc-typehints happy
+    from ax import modelbridge as modelbridge_module  # noqa F401  # pragma: no cover
 
 
 class TaskEncode(OrderedChoiceEncode):
@@ -27,11 +33,12 @@ class TaskEncode(OrderedChoiceEncode):
 
     def __init__(
         self,
-        search_space: SearchSpace,
-        observation_features: List[ObservationFeatures],
-        observation_data: List[ObservationData],
+        search_space: Optional[SearchSpace] = None,
+        observations: Optional[List[Observation]] = None,
+        modelbridge: Optional["modelbridge_module.base.ModelBridge"] = None,
         config: Optional[TConfig] = None,
     ) -> None:
+        assert search_space is not None, "TaskEncode requires search space"
         # Identify parameters that should be transformed
         self.encoded_parameters: Dict[str, Dict[TParamValue, int]] = {}
         for p in search_space.parameters.values():
@@ -53,12 +60,12 @@ class TaskEncode(OrderedChoiceEncode):
             for p_name, transforms in self.encoded_parameters.items()
         }
 
-    def transform_search_space(self, search_space: SearchSpace) -> SearchSpace:
+    def _transform_search_space(self, search_space: SearchSpace) -> SearchSpace:
         transformed_parameters: Dict[str, Parameter] = {}
         for p_name, p in search_space.parameters.items():
             if p_name in self.encoded_parameters and isinstance(p, ChoiceParameter):
                 if p.is_fidelity:
-                    raise ValueError(
+                    raise ValueError(  # pragma: no cover
                         f"Cannot choice-encode fidelity parameter {p_name}."
                     )
                 # Choice(|K|) => Choice(0, K-1, is_task=True)
@@ -68,10 +75,12 @@ class TaskEncode(OrderedChoiceEncode):
                     values=list(range(len(p.values))),  # pyre-ignore [6]
                     is_ordered=p.is_ordered,
                     is_task=True,
+                    sort_values=True,
                 )
             else:
                 transformed_parameters[p.name] = p
-        return SearchSpace(
+        return construct_new_search_space(
+            search_space=search_space,
             parameters=list(transformed_parameters.values()),
             parameter_constraints=[
                 pc.clone_with_transformed_parameters(
