@@ -1,17 +1,22 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
-from typing import Dict, List, Optional
+from typing import Dict, List, Optional, TYPE_CHECKING
 
 import numpy as np
-from ax.core.observation import ObservationData, ObservationFeatures
+from ax.core.observation import Observation, ObservationFeatures
 from ax.core.parameter import ChoiceParameter, ParameterType
-from ax.core.search_space import SearchSpace
-from ax.core.types import TConfig
+from ax.core.search_space import RobustSearchSpace, SearchSpace
+from ax.exceptions.core import UnsupportedError
 from ax.modelbridge.transforms.base import Transform
+from ax.models.types import TConfig
+
+if TYPE_CHECKING:
+    # import as module to make sphinx-autodoc-typehints happy
+    from ax import modelbridge as modelbridge_module  # noqa F401  # pragma: no cover
 
 
 TRIAL_PARAM = "TRIAL_PARAM"
@@ -42,13 +47,18 @@ class TrialAsTask(Transform):
 
     def __init__(
         self,
-        search_space: SearchSpace,
-        observation_features: List[ObservationFeatures],
-        observation_data: List[ObservationData],
+        search_space: Optional[SearchSpace] = None,
+        observations: Optional[List[Observation]] = None,
+        modelbridge: Optional["modelbridge_module.base.ModelBridge"] = None,
         config: Optional[TConfig] = None,
     ) -> None:
+        assert observations is not None, "TrialAskTask requires observations"
         # Identify values of trial.
-        trials = {obsf.trial_index for obsf in observation_features}
+        trials = {obs.features.trial_index for obs in observations}
+        if isinstance(search_space, RobustSearchSpace):
+            raise UnsupportedError(
+                "TrialAsTask transform is not supported for RobustSearchSpace."
+            )
         if None in trials:
             raise ValueError(
                 "Unable to use trial as task since not all observations have "
@@ -95,13 +105,15 @@ class TrialAsTask(Transform):
                 obsf.trial_index = None
         return observation_features
 
-    def transform_search_space(self, search_space: SearchSpace) -> SearchSpace:
+    def _transform_search_space(self, search_space: SearchSpace) -> SearchSpace:
         for p_name, level_dict in self.trial_level_map.items():
             level_values = sorted(set(level_dict.values()))
-            if len(level_values) == 1:
+            if len(level_values) < 2:
+                details = (
+                    f"only 1 found: {level_values}" if level_values else "none found"
+                )
                 raise ValueError(
-                    "TrialAsTask transform expects 2+ task params, "
-                    + f"only 1 found: {level_values}"
+                    f"TrialAsTask transform expects 2+ task params, {details}"
                 )
             trial_param = ChoiceParameter(
                 name=p_name,
@@ -114,6 +126,7 @@ class TrialAsTask(Transform):
                 values=level_values,
                 is_ordered=False,
                 is_task=True,
+                sort_values=True,
             )
             search_space.add_parameter(trial_param)
         return search_space
@@ -125,7 +138,6 @@ class TrialAsTask(Transform):
             for p_name in self.trial_level_map:
                 pval = obsf.parameters.pop(p_name)
             if self.inverse_map is not None:
-                # pyre-fixme[16]: `Optional` has no attribute `__getitem__`.
                 # pyre-fixme[61]: `pval` may not be initialized here.
                 obsf.trial_index = np.int64(self.inverse_map[pval])
         return observation_features
