@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -11,8 +11,9 @@ from operator import mul
 from typing import Dict, List, Optional, Tuple
 
 import numpy as np
-from ax.core.types import TConfig, TGenMetadata, TParamValue, TParamValueList
+from ax.core.types import TGenMetadata, TParamValue, TParamValueList
 from ax.models.discrete_base import DiscreteModel
+from ax.models.types import TConfig
 from ax.utils.common.docutils import copy_doc
 from ax.utils.common.logger import get_logger
 
@@ -45,8 +46,6 @@ class FullFactorialGenerator(DiscreteModel):
         self.max_cardinality = max_cardinality
         self.check_cardinality = check_cardinality
 
-    # pyre-fixme[56]: While applying decorator
-    #  `ax.utils.common.docutils.copy_doc(...)`: Argument `n` expected.
     @copy_doc(DiscreteModel.gen)
     def gen(
         self,
