@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -9,21 +9,18 @@ from __future__ import annotations
 import itertools
 import warnings
 from collections import defaultdict
-from typing import TYPE_CHECKING, Callable, Dict, List, Optional, Set, Tuple, Union
+from typing import Callable, Dict, List, Optional, Set, Tuple, Union
 
 import numpy as np
 import torch
 from ax.core.search_space import SearchSpaceDigest
-from ax.core.types import TConfig, TParamCounter
+from ax.core.types import TParamCounter
 from ax.exceptions.core import SearchSpaceExhausted
-from ax.models.numpy_base import NumpyModel
 from ax.models.torch_base import TorchModel
+from ax.models.types import TConfig
+from botorch.acquisition.risk_measures import RiskMeasureMCObjective
 
 
-if TYPE_CHECKING:
-    # import as module to make sphinx-autodoc-typehints happy
-    from ax import models  # noqa F401  # pragma: no cover
-
 Tensoray = Union[torch.Tensor, np.ndarray]
 
 
@@ -232,12 +229,13 @@ def validate_bounds(
 
 
 def best_observed_point(
-    model: Union[NumpyModel, TorchModel],
+    model: TorchModel,
     bounds: List[Tuple[float, float]],
     objective_weights: Optional[Tensoray],
     outcome_constraints: Optional[Tuple[Tensoray, Tensoray]] = None,
     linear_constraints: Optional[Tuple[Tensoray, Tensoray]] = None,
     fixed_features: Optional[Dict[int, float]] = None,
+    risk_measure: Optional[RiskMeasureMCObjective] = None,
     options: Optional[TConfig] = None,
 ) -> Optional[Tensoray]:
     """Select the best point that has been observed.
@@ -283,6 +281,7 @@ def best_observed_point(
             A x <= b.
         fixed_features: A map {feature_index: value} for features that
             should be fixed to a particular value in the best point.
+        risk_measure: An optional risk measure for reporting best robust point.
         options: A config dictionary with settings described above.
 
     Returns:
@@ -298,6 +297,7 @@ def best_observed_point(
         outcome_constraints=outcome_constraints,
         linear_constraints=linear_constraints,
         fixed_features=fixed_features,
+        risk_measure=risk_measure,
         options=options,
     )
     return None if best_point_and_value is None else best_point_and_value[0]
@@ -305,12 +305,13 @@ def best_observed_point(
 
 def best_in_sample_point(
     Xs: Union[List[torch.Tensor], List[np.ndarray]],
-    model: Union[NumpyModel, TorchModel],
+    model: TorchModel,
     bounds: List[Tuple[float, float]],
     objective_weights: Optional[Tensoray],
     outcome_constraints: Optional[Tuple[Tensoray, Tensoray]] = None,
     linear_constraints: Optional[Tuple[Tensoray, Tensoray]] = None,
     fixed_features: Optional[Dict[int, float]] = None,
+    risk_measure: Optional[RiskMeasureMCObjective] = None,
     options: Optional[TConfig] = None,
 ) -> Optional[Tuple[Tensoray, float]]:
     """Select the best point that has been observed.
@@ -357,6 +358,7 @@ def best_in_sample_point(
             A x <= b.
         fixed_features: A map {feature_index: value} for features that
             should be fixed to a particular value in the best point.
+        risk_measure: An optional risk measure for reporting best robust point.
         options: A config dictionary with settings described above.
 
     Returns:
@@ -364,6 +366,11 @@ def best_in_sample_point(
         - d-array of the best point,
         - utility at the best point.
     """
+    if risk_measure is not None:
+        # TODO[T131759268]: We need to apply the risk measure. Instead of doing obj_w @,
+        # we could use `get_botorch_objective_and_transform` to get the objective
+        # then apply it, though we also need to decide how to deal with constraints.
+        raise NotImplementedError  # pragma: no cover
     # Parse options
     if options is None:
         options = {}
@@ -479,19 +486,13 @@ def get_observed(
             {tuple(float(x_i) for x_i in x) for x in Xs[idx]}
         )
     if isinstance(Xs[0], np.ndarray):
-        # pyre-fixme[6]: Expected `Union[None, Dict[str, Tuple[typing.Any, int]],
-        #  Dict[str, Union[typing.Sequence[typing.Any], typing.Sequence[Union[None,
-        #  bytes, str]], typing.Sequence[int], typing.Sequence[str], int]],
-        #  List[Union[Tuple[Union[Tuple[str, str], str], typing.Any],
-        #  Tuple[Union[Tuple[str, str], str], typing.Any, Union[typing.Sequence[int],
-        #  int]]]], Tuple[typing.Any, typing.Any], Tuple[typing.Any,
-        #  Union[typing.Sequence[int], int]], Tuple[typing.Any, int],
-        #  typing.Type[typing.Any], np.dtype, str]` for 2nd param but got
-        #  `Union[np.dtype, torch.dtype]`.
+        # pyre-fixme[6]: For 2nd param expected `Union[None, Dict[str, Tuple[typing.A...
         return np.array(list(X_obs_set), dtype=Xs[0].dtype)  # (n x d)
     if isinstance(Xs[0], torch.Tensor):
         # pyre-fixme[7]: Expected `Union[np.ndarray, torch.Tensor]` but got implicit
         #  return value of `None`.
+        # pyre-fixme[6]: For 3rd param expected `Optional[_C.dtype]` but got
+        #  `Union[np.dtype, _C.dtype]`.
         return torch.tensor(list(X_obs_set), device=Xs[0].device, dtype=Xs[0].dtype)
 
 
