@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -10,7 +10,7 @@ from ax.utils.common.testutils import TestCase
 
 
 class ALEBOSobolTest(TestCase):
-    def testALEBOSobolModel(self):
+    def testALEBOSobolModel(self) -> None:
         B = np.array([[1.0, 2.0, 3.0], [2.0, 3.0, 4.0]])
         Q = np.linalg.pinv(B) @ B
         # Test setting attributes
