@@ -21,7 +21,7 @@ References
 
 from __future__ import annotations
 
-from typing import Any, Callable, Dict, List, Optional, Tuple
+from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 
 import torch
 from ax.exceptions.core import AxError
@@ -41,6 +41,9 @@ from botorch.acquisition.multi_objective.utils import get_default_partitioning_a
 from botorch.acquisition.utils import get_acquisition_function
 from botorch.models.model import Model
 from botorch.optim.optimize import optimize_acqf_list
+from botorch.posteriors.gpytorch import GPyTorchPosterior
+from botorch.posteriors.posterior import Posterior
+from botorch.posteriors.posterior_list import PosteriorList
 from botorch.utils.multi_objective.hypervolume import infer_reference_point
 from botorch.utils.multi_objective.pareto import is_non_dominated
 from torch import Tensor
@@ -215,7 +218,7 @@ def get_EHVI(
         objective_weights=objective_weights, objective_thresholds=objective_thresholds
     )
     with torch.no_grad():
-        Y = model.posterior(X_observed).mean
+        Y = _check_posterior_type(model.posterior(X_observed)).mean
     # For EHVI acquisition functions we pass the constraint transform directly.
     if outcome_constraints is None:
         cons_tfs = None
@@ -505,7 +508,10 @@ def infer_objective_thresholds(
                 outcome_constraints[1],
             )
     with torch.no_grad():
-        pred = not_none(model).posterior(not_none(X_observed)).mean
+        pred = _check_posterior_type(
+            not_none(model).posterior(not_none(X_observed))
+        ).mean
+
     if outcome_constraints is not None:
         cons_tfs = get_outcome_constraint_transforms(outcome_constraints)
         # pyre-ignore [16]
@@ -533,3 +539,15 @@ def infer_objective_thresholds(
     obj_idcs = subset_idcs[obj_mask]
     full_objective_thresholds[obj_idcs] = objective_thresholds.clone()
     return full_objective_thresholds
+
+
+def _check_posterior_type(
+    posterior: Posterior,
+) -> Union[GPyTorchPosterior, PosteriorList]:
+    """Check whether the posterior type is  `GPyTorchPosterior` or `PosteriorList`."""
+    if isinstance(posterior, GPyTorchPosterior) or isinstance(posterior, PosteriorList):
+        return posterior
+    else:
+        raise ValueError(
+            f"Value was not of type GPyTorchPosterior or PosteriorList:\n{posterior}"
+        )
