@@ -1,9 +1,10 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
+from logging import Logger
 from typing import Any, Dict, List, Optional
 
 from ax.core.search_space import SearchSpaceDigest
@@ -12,16 +13,17 @@ from ax.models.torch.botorch import BotorchModel
 from ax.models.torch_base import TorchModel
 from ax.utils.common.docutils import copy_doc
 from ax.utils.common.logger import get_logger
-from botorch.fit import fit_gpytorch_model
+from botorch.fit import fit_gpytorch_mll
 from botorch.models.contextual import SACGP
 from botorch.models.gpytorch import GPyTorchModel
 from botorch.models.model_list_gp_regression import ModelListGP
+from botorch.utils.datasets import SupervisedDataset
 from gpytorch.mlls.exact_marginal_log_likelihood import ExactMarginalLogLikelihood
 from torch import Tensor
 
 
 MIN_OBSERVED_NOISE_LEVEL = 1e-7
-logger = get_logger(__name__)
+logger: Logger = get_logger(__name__)
 
 
 class SACBO(BotorchModel):
@@ -47,22 +49,18 @@ class SACBO(BotorchModel):
     @copy_doc(TorchModel.fit)
     def fit(
         self,
-        Xs: List[Tensor],
-        Ys: List[Tensor],
-        Yvars: List[Tensor],
-        search_space_digest: SearchSpaceDigest,
+        datasets: List[SupervisedDataset],
         metric_names: List[str],
+        search_space_digest: SearchSpaceDigest,
         candidate_metadata: Optional[List[List[TCandidateMetadata]]] = None,
     ) -> None:
         if len(search_space_digest.feature_names) == 0:
             raise ValueError("feature names are required for SACBO")
         self.feature_names = search_space_digest.feature_names
         super().fit(
-            Xs=Xs,
-            Ys=Ys,
-            Yvars=Yvars,
-            search_space_digest=search_space_digest,
+            datasets=datasets,
             metric_names=metric_names,
+            search_space_digest=search_space_digest,
         )
 
     def get_and_fit_model(
@@ -94,7 +92,7 @@ class SACBO(BotorchModel):
             Yvar = Yvars[i].clamp_min_(MIN_OBSERVED_NOISE_LEVEL)
             gp_m = SACGP(X, Ys[i], Yvar, decomp_index)
             mll = ExactMarginalLogLikelihood(gp_m.likelihood, gp_m)
-            fit_gpytorch_model(mll)
+            fit_gpytorch_mll(mll)
             models.append(gp_m)
 
         if len(models) == 1:
