@@ -34,7 +34,6 @@ from logging import Logger
 from typing import Any, Callable, Dict, List, Optional, Tuple
 
 import numpy as np
-import pyro  # @manual=//third-party-source/native/pyro:pyro
 import torch
 from ax.exceptions.core import AxError
 from ax.models.torch.botorch import (
@@ -65,10 +64,13 @@ from ax.models.torch.fully_bayesian_model_utils import (
 )
 from ax.utils.common.docutils import copy_doc
 from ax.utils.common.logger import get_logger
+from ax.utils.common.typeutils import checked_cast
 from botorch.acquisition import AcquisitionFunction
+from botorch.models.fully_bayesian import _psd_safe_pyro_mvn_sample
 from botorch.models.gpytorch import GPyTorchModel
 from botorch.models.model import Model
 from botorch.models.model_list_gp_regression import ModelListGP
+from botorch.posteriors.gpytorch import GPyTorchPosterior
 from torch import Tensor
 
 logger: Logger = get_logger(__name__)
@@ -97,7 +99,7 @@ def predict_from_model_mcmc(model: Model, X: Tensor) -> Tuple[Tensor, Tensor]:
     """
     with torch.no_grad():
         # compute the batch (independent posterior over the inputs)
-        posterior = model.posterior(X.unsqueeze(-3))
+        posterior = checked_cast(GPyTorchPosterior, model.posterior(X.unsqueeze(-3)))
     # the mean and variance both have shape: n x num_samples x m (after squeezing)
     mean = posterior.mean.cpu().detach()
     # TODO: Allow Posterior to (optionally) return the full covariance matrix
@@ -207,7 +209,7 @@ def single_task_pyro_model(
     mean = pyro_sample_mean(**tkwargs)
     if torch.isnan(Yvar).all():
         # infer noise level
-        noise = pyro_sample_noise(**tkwargs)
+        noise = MIN_OBSERVED_NOISE_LEVEL + pyro_sample_noise(**tkwargs)
     else:
         noise = Yvar.clamp_min(MIN_OBSERVED_NOISE_LEVEL)
     # pyre-fixme[6]: For 2nd param expected `float` but got `Union[device, dtype]`.
@@ -232,12 +234,10 @@ def single_task_pyro_model(
     # add noise
     k = outputscale * k + noise * torch.eye(X.shape[0], dtype=X.dtype, device=X.device)
 
-    pyro.sample(
-        "Y",
-        pyro.distributions.MultivariateNormal(  # pyre-ignore [16]
-            loc=mean.view(-1).expand(X.shape[0]),
-            covariance_matrix=k,
-        ),
+    _psd_safe_pyro_mvn_sample(
+        name="Y",
+        loc=mean.view(-1).expand(X.shape[0]),
+        covariance_matrix=k,
         obs=Y,
     )
 
@@ -392,10 +392,10 @@ def run_inference(
 ) -> Dict[str, Tensor]:
     start = time.time()
     try:
-        # @manual=//third-party-source/native/pyro:pyro
+        # @manual=fbsource//third-party/pypi/pyro-ppl:pyro-ppl
         from pyro.infer.mcmc import MCMC, NUTS
 
-        # @manual=//third-party-source/native/pyro:pyro
+        # @manual=fbsource//third-party/pypi/pyro-ppl:pyro-ppl
         from pyro.infer.mcmc.util import print_summary
     except ImportError:  # pragma: no cover
         raise RuntimeError("Cannot call run_inference without pyro installed!")
