@@ -4,18 +4,23 @@
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
+from collections import defaultdict
 from functools import reduce
 
 from logging import Logger
-from typing import Dict, Iterable, Optional, Tuple, Type
+from typing import Dict, Iterable, List, Optional, Tuple, Type
 
+import numpy as np
 import pandas as pd
+import torch
 from ax.core.arm import Arm
+from ax.core.base_trial import TrialStatus
 from ax.core.batch_trial import BatchTrial
 from ax.core.data import Data
 from ax.core.experiment import Experiment
 from ax.core.generator_run import GeneratorRun
 from ax.core.objective import Objective, ScalarizedObjective
+from ax.core.observation import Observation
 from ax.core.optimization_config import (
     MultiObjectiveOptimizationConfig,
     OptimizationConfig,
@@ -24,6 +29,7 @@ from ax.core.outcome_constraint import OutcomeConstraint
 from ax.core.trial import Trial
 from ax.core.types import ComparisonOp, TModelPredictArm, TParameterization
 from ax.exceptions.core import UnsupportedError, UserInputError
+from ax.modelbridge.base import ModelBridge
 from ax.modelbridge.cross_validation import (
     assess_model_fit,
     compute_diagnostics,
@@ -40,10 +46,15 @@ from ax.modelbridge.registry import (
     Models,
 )
 from ax.modelbridge.torch import TorchModelBridge
+from ax.modelbridge.transforms.utils import (
+    derelativize_optimization_config_with_raw_status_quo,
+)
+from ax.plot.pareto_utils import get_tensor_converter_model
 from ax.utils.common.logger import get_logger
 from ax.utils.common.typeutils import checked_cast, not_none
 from ax.utils.stats.statstools import relativize_data
 from numpy import NaN
+from torch import Tensor
 
 logger: Logger = get_logger(__name__)
 
@@ -616,20 +627,21 @@ def _get_best_row_for_single_objective(
     )
 
 
-def _filter_feasible_rows(
+def _is_row_feasible(
     df: pd.DataFrame,
     optimization_config: OptimizationConfig,
     status_quo: Optional[Arm],
-) -> pd.DataFrame:
-    """Filter out arms that do not satisfy outcome constraints
+) -> pd.Series:
+    """Return a series of boolean values indicating whether arms satisfy outcome
+    constraints or not.
 
-    Looks at all arm data collected and removes rows corresponding to arms in
+    Looks at all arm data collected and returns False for rows corresponding to arms in
     which one or more of their associated metrics' 95% confidence interval
     falls outside of any outcome constraint's bounds (i.e. we are 95% sure the
-    bound is not satisfied).
+    bound is not satisfied), else True.
     """
-    if len(optimization_config.outcome_constraints) < 1:
-        return df
+    if len(optimization_config.all_constraints) < 1:
+        return pd.Series([True] * len(df), index=df.index)
 
     name = df["metric_name"]
 
@@ -645,7 +657,7 @@ def _filter_feasible_rows(
     rel_lower_bound = None
     rel_upper_bound = None
     if status_quo is not None and any(
-        oc.relative for oc in optimization_config.outcome_constraints
+        oc.relative for oc in optimization_config.all_constraints
     ):
         # relativize_data expects all arms to come from the same trial, we need to
         # format the data as if it was.
@@ -694,25 +706,47 @@ def _filter_feasible_rows(
         # Return True if metrics are different, or whether the confidence
         # interval is entirely not within the bound
         if oc.op == ComparisonOp.GEQ:
-            return ~name_match_mask | (observed_upper_bound > oc.bound)
+            return ~name_match_mask | (observed_upper_bound > float(oc.bound))
         else:
-            return ~name_match_mask | (observed_lower_bound < oc.bound)
+            return ~name_match_mask | (observed_lower_bound < float(oc.bound))
 
     mask = reduce(
         lambda left, right: left & right,
-        map(oc_mask, optimization_config.outcome_constraints),
+        map(oc_mask, optimization_config.all_constraints),
     )
     bad_arm_names = (
         df[~mask]["arm_name"].tolist()
         if rel_df is None
         else rel_df[~mask]["arm_name"].tolist()
     )
-    feasible = df.loc[df["arm_name"].apply(lambda x: x not in bad_arm_names)]
+    return checked_cast(
+        pd.Series, df["arm_name"].apply(lambda x: x not in bad_arm_names)
+    )
+
+
+def _filter_feasible_rows(
+    df: pd.DataFrame,
+    optimization_config: OptimizationConfig,
+    status_quo: Optional[Arm],
+) -> pd.DataFrame:
+    """Filter out arms that do not satisfy outcome constraints
+
+    Looks at all arm data collected and removes rows corresponding to arms in
+    which one or more of their associated metrics' 95% confidence interval
+    falls outside of any outcome constraint's bounds (i.e. we are 95% sure the
+    bound is not satisfied).
+    """
+
+    feasible = df.loc[
+        _is_row_feasible(
+            df=df, optimization_config=optimization_config, status_quo=status_quo
+        )
+    ]
 
     if feasible.empty:
         raise ValueError(
             "No points satisfied all outcome constraints within 95 percent"
-            + "confidence interval"
+            "confidence interval."
         )
 
     return feasible
@@ -727,3 +761,93 @@ def _is_all_noiseless(df: pd.DataFrame, metric_name: str) -> bool:
     df_metric_arms_sems = df[name_mask]["sem"]
 
     return ((df_metric_arms_sems == 0) | df_metric_arms_sems == NaN).all()
+
+
+def _derel_opt_config_wrapper(
+    optimization_config: OptimizationConfig,
+    modelbridge: Optional[ModelBridge] = None,
+    experiment: Optional[Experiment] = None,
+    observations: Optional[List[Observation]] = None,
+) -> OptimizationConfig:
+    """Derelativize optimization_config using raw status-quo values"""
+
+    # If optimization_config is already derelativized, return a copy.
+    if not any(oc.relative for oc in optimization_config.all_constraints):
+        return optimization_config.clone()
+
+    if modelbridge is None and experiment is None:
+        raise ValueError(
+            "Must specify ModelBridge or Experiment when calling "
+            "`_derel_opt_config_wrapper`."
+        )
+    elif not modelbridge:
+        modelbridge = get_tensor_converter_model(
+            experiment=not_none(experiment),
+            data=not_none(experiment).lookup_data(),
+        )
+    else:  # Both modelbridge and experiment specified.
+        logger.warning(
+            "ModelBridge and Experiment provided to `_derel_opt_config_wrapper`. "
+            "Ignoring the latter."
+        )
+    if not modelbridge.status_quo:
+        raise ValueError(
+            "`modelbridge` must have status quo if specified. If `modelbridge` is "
+            "unspecified, `experiment` must have a status quo."
+        )
+    observations = observations or modelbridge.get_training_data()
+    return derelativize_optimization_config_with_raw_status_quo(
+        optimization_config=optimization_config,
+        modelbridge=modelbridge,
+        observations=observations,
+    )
+
+
+def extract_Y_from_data(
+    experiment: Experiment,
+    metric_names: List[str],
+    data: Optional[Data] = None,
+) -> Tensor:
+    r"""Converts the experiment observation data into a tensor.
+
+    NOTE: This assumes block design for observations. It will
+    error out if any trial is missing data for any of the given
+    metrics or if the data is missing the `trial_index`.
+
+    Args:
+        experiment: The experiment to extract the data from.
+        metric_names: List of metric names to extract data for.
+        data: An optional `Data` object to use instead of the
+            experiment data. Note that the experiment must have
+            a corresponding COMPLETED or EARLY_STOPPED trial for
+            each `trial_index` in the `data`.
+
+    Returns:
+        A tensor of observed metrics.
+    """
+    df = data.df if data is not None else experiment.lookup_data().df
+    if len(df) == 0:
+        return torch.empty(0, len(metric_names), dtype=torch.double)
+    trial_indices = np.sort(np.unique(df["trial_index"].values))
+    Y_lists_dict = defaultdict(list)
+    data_by_trial = df.groupby("trial_index")
+    for trial_idx in trial_indices:
+        trial = experiment.trials[trial_idx]
+        if trial.status not in [TrialStatus.COMPLETED, TrialStatus.EARLY_STOPPED]:
+            # Skip trials that are not completed or early stopped.
+            continue
+        if isinstance(trial, BatchTrial):
+            raise UnsupportedError("BatchTrials are not supported.")
+        trial_data = data_by_trial.get_group(trial_idx)
+        try:
+            for m in metric_names:
+                Y_lists_dict[m].append(
+                    float(trial_data.loc[trial_data["metric_name"] == m, "mean"])
+                )
+        except (KeyError, TypeError):
+            raise UserInputError(
+                "Expected each trial to have a single data point for each metric."
+                f"Got {trial_data} for trial {trial_idx}."
+            )
+
+    return torch.tensor([Y_lists_dict[m] for m in metric_names], dtype=torch.double).T
