@@ -93,6 +93,28 @@ class MetricObjective(enum.Enum):
 
 @dataclass
 class ObjectiveProperties:
+    r"""Class that holds properties of objective functions. Can be used to define an
+    the `objectives` argument of ax_client.create_experiment, e.g.:
+
+        ax_client.create_experiment(
+            name="moo_experiment",
+            parameters=[...],
+            objectives={
+                # `threshold` arguments are optional
+                "a": ObjectiveProperties(minimize=False, threshold=ref_point[0]),
+                "b": ObjectiveProperties(minimize=False, threshold=ref_point[1]),
+            },
+        )
+
+    Args:
+        - minimize: Boolean indicating whether the objective is to be minimized
+            or maximized.
+        - threshold: Optional `float` representing the smallest objective value
+            (resp. largest if minimize=True) that is considered valuable in the context
+            of multi-objective optimization. In BoTorch and in the literature, this is
+            also known as an element of the reference point vector that defines the
+            hyper-volume of the Pareto front.
+    """
     minimize: bool
     threshold: Optional[float] = None
 
@@ -873,8 +895,6 @@ class InstantiationBase:
     def raw_data_to_evaluation(
         raw_data: TEvaluationOutcome,
         metric_names: List[str],
-        start_time: Optional[int] = None,
-        end_time: Optional[int] = None,
     ) -> TEvaluationOutcome:
         """Format the trial evaluation data to a standard `TTrialEvaluation`
         (mapping from metric names to a tuple of mean and SEM) representation, or
@@ -923,8 +943,8 @@ class InstantiationBase:
         metric_names: List[str],
         trial_index: int,
         sample_sizes: Dict[str, int],
-        start_time: Optional[int] = None,
-        end_time: Optional[int] = None,
+        start_time: Optional[Union[int, str]] = None,
+        end_time: Optional[Union[int, str]] = None,
     ) -> Tuple[Dict[str, TEvaluationOutcome], Data]:
         """Transforms evaluations into Ax Data.
 
@@ -939,16 +959,18 @@ class InstantiationBase:
             sample_sizes: Number of samples collected for each arm, may be empty
                 if unavailable.
             start_time: Optional start time of run of the trial that produced this
-                data, in milliseconds.
+                data, in milliseconds or iso format.  Milliseconds will eventually be
+                converted to iso format because iso format automatically works with the
+                pandas column type `Timestamp`.
             end_time: Optional end time of run of the trial that produced this
-                data, in milliseconds.
+                data, in milliseconds or iso format.  Milliseconds will eventually be
+                converted to iso format because iso format automatically works with the
+                pandas column type `Timestamp`.
         """
         evaluations = {
             arm_name: cls.raw_data_to_evaluation(
                 raw_data=raw_data[arm_name],
                 metric_names=metric_names,
-                start_time=start_time,
-                end_time=end_time,
             )
             for arm_name in raw_data
         }
