@@ -38,6 +38,7 @@ from ax.modelbridge.cross_validation import cross_validate
 from ax.plot.contour import interact_contour_plotly
 from ax.plot.diagnostic import interact_cross_validation_plotly
 from ax.plot.feature_importances import plot_feature_importance_by_feature_plotly
+from ax.plot.helper import get_range_parameters_from_list
 from ax.plot.pareto_frontier import (
     _pareto_frontier_plot_input_processing,
     _validate_experiment_and_get_optimization_config,
@@ -47,6 +48,7 @@ from ax.plot.pareto_utils import _extract_observed_pareto_2d
 from ax.plot.scatter import interact_fitted_plotly, plot_multiple_metrics
 from ax.plot.slice import interact_slice_plotly
 from ax.plot.trace import optimization_trace_single_method_plotly
+from ax.service.utils.best_point import _is_row_feasible
 from ax.utils.common.logger import get_logger
 from ax.utils.common.typeutils import checked_cast, not_none
 from pandas.core.frame import DataFrame
@@ -62,9 +64,10 @@ FEATURE_IMPORTANCE_CAPTION = (
     "relatively low importance may still be important to tune."
 )
 CROSS_VALIDATION_CAPTION = (
-    "<b>NOTE:</b> We have tried out best to only plot the region of interest.<br>"
+    "<b>NOTE:</b> We have tried our best to only plot the region of interest.<br>"
     "This may hide outliers. You can autoscale the axes to see all trials."
 )
+FEASIBLE_COL_NAME = "is_feasible"
 
 
 def _get_hypervolume_trace() -> None:
@@ -142,7 +145,9 @@ def _get_objective_v_param_plots(
 ) -> List[go.Figure]:
     search_space = experiment.search_space
 
-    range_params = list(search_space.range_parameters.keys())
+    range_params = get_range_parameters_from_list(
+        list(search_space.range_parameters.values()), min_num_values=5
+    )
     if len(range_params) < 1:
         # if search space contains no range params
         logger.warning(
@@ -413,11 +418,16 @@ def _merge_trials_dict_with_df(
 
 
 def _get_generation_method_str(trial: BaseTrial) -> str:
+    trial_generation_property = trial._properties.get("generation_model_key")
+    if trial_generation_property is not None:
+        return trial_generation_property
+
     generation_methods = {
         not_none(generator_run._model_key)
         for generator_run in trial.generator_runs
         if generator_run._model_key is not None
     }
+
     # add "Manual" if any generator_runs are manual
     if any(
         generator_run.generator_run_type == GeneratorRunType.MANUAL.name
@@ -429,7 +439,7 @@ def _get_generation_method_str(trial: BaseTrial) -> str:
 
 def _merge_results_if_no_duplicates(
     arms_df: pd.DataFrame,
-    data: Data,
+    results: pd.DataFrame,
     key_components: List[str],
     metrics: List[Metric],
 ) -> DataFrame:
@@ -440,8 +450,6 @@ def _merge_results_if_no_duplicates(
         - after any formatting, ``data.df`` contains no duplicates of the column
             ``results_key_col``
     """
-    results = data.df
-
     if len(results.index) == 0:
         logger.info(
             f"No results present for the specified metrics `{metrics}`. "
@@ -473,7 +481,10 @@ def _merge_results_if_no_duplicates(
     ).reset_index()
 
     # dedupe results by key_components
-    metadata = results[key_components + [results_key_col]].drop_duplicates()
+    metadata_cols = key_components + [results_key_col]
+    if FEASIBLE_COL_NAME in results.columns:
+        metadata_cols.append(FEASIBLE_COL_NAME)
+    metadata = results[metadata_cols].drop_duplicates()
     metrics_df = pd.merge(metric_vals, metadata, on=results_key_col)
     # drop synthetic key column
     metrics_df = metrics_df.drop(results_key_col, axis=1)
@@ -537,9 +548,25 @@ def exp_to_df(
             for arm in trial.arms
         ]
     )
-    # Fetch results; in case arms_df is empty, return empty results (legacy behavior)
+    # Fetch results.
     data = exp.lookup_data()
     results = data.df
+
+    # Add `FEASIBLE_COL_NAME` column according to constraints if any.
+    if (
+        exp.optimization_config is not None
+        and len(not_none(exp.optimization_config).all_constraints) > 0
+    ):
+        try:
+            results[FEASIBLE_COL_NAME] = _is_row_feasible(
+                df=results,
+                optimization_config=not_none(exp.optimization_config),
+                status_quo=exp.status_quo,
+            )
+        except ValueError as e:
+            logger.warning(e)
+
+    # If arms_df is empty, return empty results (legacy behavior)
     if len(arms_df.index) == 0:
         if len(results.index) != 0:
             raise ValueError(
@@ -605,7 +632,7 @@ def exp_to_df(
             )
     exp_df = _merge_results_if_no_duplicates(
         arms_df=arms_df,
-        data=data,
+        results=results,
         key_components=key_components,
         metrics=metrics or list(exp.metrics.values()),
     )
