@@ -1,27 +1,29 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
 import time
-from logging import INFO
-from typing import List, Optional, Tuple, Type
+
+from logging import INFO, Logger
+from typing import Any, Dict, List, Optional, Tuple, Type
 
 from ax.core.base_trial import BaseTrial
 from ax.core.experiment import Experiment
 from ax.core.generator_run import GeneratorRun
-from ax.exceptions.core import UnsupportedError
+from ax.exceptions.core import ObjectNotFoundError, UnsupportedError
 from ax.modelbridge.generation_strategy import GenerationStrategy
 from ax.utils.common.executils import retry_on_exception
 from ax.utils.common.logger import _round_floats_for_logging, get_logger
 from ax.utils.common.typeutils import not_none
 
-
 RETRY_EXCEPTION_TYPES: Tuple[Type[Exception], ...] = ()
 
 try:  # We don't require SQLAlchemy by default.
     from ax.storage.sqa_store.db import init_engine_and_session_factory
+    from ax.storage.sqa_store.decoder import Decoder
+    from ax.storage.sqa_store.encoder import Encoder
     from ax.storage.sqa_store.load import (
         _get_experiment_id,
         _get_generation_strategy_id,
@@ -29,12 +31,13 @@ try:  # We don't require SQLAlchemy by default.
         _load_generation_strategy_by_experiment_name,
     )
     from ax.storage.sqa_store.save import (
-        _save_or_update_trials,
         _save_experiment,
         _save_generation_strategy,
+        _save_or_update_trials,
         _update_generation_strategy,
         update_properties_on_experiment,
     )
+    from ax.storage.sqa_store.sqa_config import SQAConfig
     from ax.storage.sqa_store.structs import DBSettings
     from sqlalchemy.exc import OperationalError
     from sqlalchemy.orm.exc import StaleDataError
@@ -43,11 +46,15 @@ try:  # We don't require SQLAlchemy by default.
     RETRY_EXCEPTION_TYPES = (OperationalError, StaleDataError)
 except ModuleNotFoundError:  # pragma: no cover
     DBSettings = None
+    Decoder = None
+    Encoder = None
+    SQAConfig = None
 
 
 STORAGE_MINI_BATCH_SIZE = 50
+LOADING_MINI_BATCH_SIZE = 10000
 
-logger = get_logger(__name__)
+logger: Logger = get_logger(__name__)
 
 
 class WithDBSettingsBase:
@@ -57,22 +64,40 @@ class WithDBSettingsBase:
 
     _db_settings: Optional[DBSettings] = None
 
+    # Mapping of object types to mapping of fields to override values
+    # loaded objects will all be instantiated with fields set to
+    # override value
+    # current valid object types are: "runner"
+    AX_OBJECT_FIELD_OVERRIDES: Dict[str, Any] = {}
+
     def __init__(
-        self, db_settings: Optional[DBSettings] = None, logging_level: int = INFO
+        self,
+        db_settings: Optional[DBSettings] = None,
+        logging_level: int = INFO,
+        suppress_all_errors: bool = False,
     ) -> None:
         if db_settings and (not DBSettings or not isinstance(db_settings, DBSettings)):
             raise ValueError(
                 "`db_settings` argument should be of type ax.storage.sqa_store."
+                f"(Got: {db_settings} of type {type(db_settings)}. "
                 "structs.DBSettings. To use `DBSettings`, you will need SQLAlchemy "
                 "installed in your environment (can be installed through pip)."
             )
-        self._db_settings = db_settings
+        self._db_settings = db_settings or self._get_default_db_settings()
+        self._suppress_all_errors = suppress_all_errors
         if self.db_settings_set:
             init_engine_and_session_factory(
                 creator=self.db_settings.creator, url=self.db_settings.url
             )
         logger.setLevel(logging_level)
 
+    @staticmethod
+    def _get_default_db_settings() -> Optional[DBSettings]:
+        """Overridable method to get default db_settings
+        if none are passed in __init__
+        """
+        return None
+
     @property
     def db_settings_set(self) -> bool:
         """Whether non-None DB settings are set on this instance."""
@@ -128,8 +153,6 @@ class WithDBSettingsBase:
                 experiment_name=exp_name
             )
             if exp_id:  # Experiment in DB.
-                # TODO: Switch to just updating experiment when selective-field
-                # update is available.
                 logger.info(f"Experiment {exp_name} is in DB, updating it.")
                 self._save_experiment_to_db_if_possible(experiment=experiment)
                 saved_exp = True
@@ -200,12 +223,15 @@ class WithDBSettingsBase:
             experiment_name,
             decoder=self.db_settings.decoder,
             reduced_state=reduced_state,
+            load_trials_in_batches_of_size=LOADING_MINI_BATCH_SIZE,
+            ax_object_field_overrides=self.AX_OBJECT_FIELD_OVERRIDES,
         )
-        if not isinstance(experiment, Experiment) or experiment.is_simple_experiment:
+        if not isinstance(experiment, Experiment):
             raise ValueError("Service API only supports `Experiment`.")
         logger.info(
             f"Loaded experiment {experiment_name} in "
-            f"{_round_floats_for_logging(time.time() - start_time)} seconds."
+            f"{_round_floats_for_logging(time.time() - start_time)} seconds, "
+            f"loading trials in mini-batches of {LOADING_MINI_BATCH_SIZE}."
         )
 
         try:
@@ -220,42 +246,32 @@ class WithDBSettingsBase:
                 f"Loaded generation strategy for experiment {experiment_name} in "
                 f"{_round_floats_for_logging(time.time() - start_time)} seconds."
             )
-        except ValueError as err:
-            if "does not have a generation strategy" in str(err):
-                return experiment, None
-            raise  # `ValueError` here could signify more than just absence of GS.
+        except ObjectNotFoundError:
+            logger.info(
+                "There is no generation strategy associated with experiment "
+                f"{experiment_name}."
+            )
+
+            return experiment, None
+
         return experiment, generation_strategy
 
-    @retry_on_exception(
-        retries=3,
-        default_return_on_suppression=False,
-        exception_types=RETRY_EXCEPTION_TYPES,
-    )
-    def _save_experiment_to_db_if_possible(
-        self, experiment: Experiment, suppress_all_errors: bool = False
-    ) -> bool:
+    def _save_experiment_to_db_if_possible(self, experiment: Experiment) -> bool:
         """Saves attached experiment and generation strategy if DB settings are
         set on this `WithDBSettingsBase` instance.
 
         Args:
             experiment: Experiment to save new trials in DB.
-            suppress_all_errors: Flag for `retry_on_exception` that makes
-                the decorator suppress the thrown exception even if it
-                occurred in all the retries (exception is still logged).
 
         Returns:
             bool: Whether the experiment was saved.
         """
         if self.db_settings_set:
-            start_time = time.time()
-            _save_experiment(
-                experiment,
+            _save_experiment_to_db_if_possible(
+                experiment=experiment,
                 encoder=self.db_settings.encoder,
                 decoder=self.db_settings.decoder,
-            )
-            logger.debug(
-                f"Saved experiment {experiment.name} in "
-                f"{_round_floats_for_logging(time.time() - start_time)} seconds."
+                suppress_all_errors=self._suppress_all_errors,
             )
             return True
         return False
@@ -266,7 +282,7 @@ class WithDBSettingsBase:
         trials: List[BaseTrial],
         generation_strategy: GenerationStrategy,
         new_generator_runs: List[GeneratorRun],
-        suppress_all_errors: bool = False,
+        reduce_state_generator_runs: bool = False,
     ) -> None:
         """Saves new trials (and updates existing ones) on given experiment
         and updates the given generation strategy, if DB settings are set on
@@ -277,13 +293,12 @@ class WithDBSettingsBase:
             trials: Newly added or updated trials to save or update in DB.
             generation_strategy: Generation strategy to update in DB.
             new_generator_runs: Generator runs to add to generation strategy.
-            suppress_all_errors: Flag for `retry_on_exception` that makes
-                the decorator suppress the thrown exception even if it
-                occurred in all the retries (exception is still logged).
         """
         logger.debug(f"Saving or updating {len(trials)} trials in DB.")
         self._save_or_update_trials_in_db_if_possible(
-            experiment=experiment, trials=trials
+            experiment=experiment,
+            trials=trials,
+            reduce_state_generator_runs=reduce_state_generator_runs,
         )
         logger.debug(
             "Updating generation strategy in DB with "
@@ -292,6 +307,7 @@ class WithDBSettingsBase:
         self._update_generation_strategy_in_db_if_possible(
             generation_strategy=generation_strategy,
             new_generator_runs=new_generator_runs,
+            reduce_state_generator_runs=reduce_state_generator_runs,
         )
         return
 
@@ -300,7 +316,6 @@ class WithDBSettingsBase:
         self,
         experiment: Experiment,
         trial: BaseTrial,
-        suppress_all_errors: bool = False,
     ) -> bool:
         """Saves new trial on given experiment if DB settings are set on this
         `WithDBSettingsBase` instance.
@@ -308,9 +323,6 @@ class WithDBSettingsBase:
         Args:
             experiment: Experiment, on which to save new trial in DB.
             trials: Newly added trial to save.
-            suppress_all_errors: Flag for `retry_on_exception` that makes
-                the decorator suppress the thrown exception even if it
-                occurred in all the retries (exception is still logged).
 
         Returns:
             bool: Whether the trial was saved.
@@ -318,19 +330,13 @@ class WithDBSettingsBase:
         return self._save_or_update_trials_in_db_if_possible(
             experiment=experiment,
             trials=[trial],
-            suppress_all_errors=suppress_all_errors,
         )
 
-    @retry_on_exception(
-        retries=3,
-        default_return_on_suppression=False,
-        exception_types=RETRY_EXCEPTION_TYPES,
-    )
     def _save_or_update_trials_in_db_if_possible(
         self,
         experiment: Experiment,
         trials: List[BaseTrial],
-        suppress_all_errors: bool = False,
+        reduce_state_generator_runs: bool = False,
     ) -> bool:
         """Saves new trials or update existing trials on given experiment if DB
         settings are set on this `WithDBSettingsBase` instance.
@@ -338,74 +344,51 @@ class WithDBSettingsBase:
         Args:
             experiment: Experiment, on which to save new trials in DB.
             trials: Newly added trials to save.
-            suppress_all_errors: Flag for `retry_on_exception` that makes
-                the decorator suppress the thrown exception even if it
-                occurred in all the retries (exception is still logged).
 
         Returns:
             bool: Whether the trials were saved.
         """
         if self.db_settings_set:
-            start_time = time.time()
-            _save_or_update_trials(
+            _save_or_update_trials_in_db_if_possible(
                 experiment=experiment,
                 trials=trials,
                 encoder=self.db_settings.encoder,
                 decoder=self.db_settings.decoder,
-                batch_size=STORAGE_MINI_BATCH_SIZE,
-            )
-            logger.debug(
-                f"Saved or updated trials {[trial.index for trial in trials]} in "
-                f"{_round_floats_for_logging(time.time() - start_time)} seconds "
-                f"in mini-batches of {STORAGE_MINI_BATCH_SIZE}."
+                suppress_all_errors=self._suppress_all_errors,
+                reduce_state_generator_runs=reduce_state_generator_runs,
             )
             return True
         return False
 
-    @retry_on_exception(
-        retries=3,
-        default_return_on_suppression=False,
-        exception_types=RETRY_EXCEPTION_TYPES,
-    )
     def _save_generation_strategy_to_db_if_possible(
-        self, generation_strategy: GenerationStrategy, suppress_all_errors: bool = False
+        self,
+        generation_strategy: Optional[GenerationStrategy] = None,
+        suppress_all_errors: bool = False,
     ) -> bool:
         """Saves given generation strategy if DB settings are set on this
         `WithDBSettingsBase` instance.
 
         Args:
             generation_strategy: Generation strategy to save in DB.
-            suppress_all_errors: Flag for `retry_on_exception` that makes
-                the decorator suppress the thrown exception even if it
-                occurred in all the retries (exception is still logged).
 
         Returns:
             bool: Whether the generation strategy was saved.
         """
-        if self.db_settings_set:
-            start_time = time.time()
-            _save_generation_strategy(
+        if self.db_settings_set and generation_strategy is not None:
+            _save_generation_strategy_to_db_if_possible(
                 generation_strategy=generation_strategy,
                 encoder=self.db_settings.encoder,
                 decoder=self.db_settings.decoder,
-            )
-            logger.debug(
-                f"Saved generation strategy {generation_strategy.name} in "
-                f"{_round_floats_for_logging(time.time() - start_time)} seconds."
+                suppress_all_errors=self._suppress_all_errors,
             )
             return True
         return False
 
-    @retry_on_exception(
-        retries=3,
-        default_return_on_suppression=False,
-        exception_types=RETRY_EXCEPTION_TYPES,
-    )
     def _update_generation_strategy_in_db_if_possible(
         self,
         generation_strategy: GenerationStrategy,
         new_generator_runs: List[GeneratorRun],
-        suppress_all_errors: bool = False,
+        reduce_state_generator_runs: bool = False,
     ) -> bool:
         """Updates the given generation strategy with new generator runs (and with
         new current generation step if applicable) if DB settings are set
@@ -415,42 +398,155 @@ class WithDBSettingsBase:
             generation_strategy: Generation strategy to update in DB.
             new_generator_runs: New generator runs of this generation strategy
                 since its last save.
-            suppress_all_errors: Flag for `retry_on_exception` that makes
-                the decorator suppress the thrown exception even if it
-                occurred in all the retries (exception is still logged).
+
         Returns:
             bool: Whether the experiment was saved.
         """
         if self.db_settings_set:
-            start_time = time.time()
-            _update_generation_strategy(
+            _update_generation_strategy_in_db_if_possible(
                 generation_strategy=generation_strategy,
-                generator_runs=new_generator_runs,
+                new_generator_runs=new_generator_runs,
                 encoder=self.db_settings.encoder,
                 decoder=self.db_settings.decoder,
-                batch_size=STORAGE_MINI_BATCH_SIZE,
-            )
-            logger.debug(
-                f"Updated generation strategy {generation_strategy.name} in "
-                f"{_round_floats_for_logging(time.time() - start_time)} seconds in "
-                f"mini-batches of {STORAGE_MINI_BATCH_SIZE} generator runs."
+                suppress_all_errors=self._suppress_all_errors,
+                reduce_state_generator_runs=reduce_state_generator_runs,
             )
             return True
         return False
 
-    @retry_on_exception(
-        retries=3,
-        default_return_on_suppression=False,
-        exception_types=RETRY_EXCEPTION_TYPES,
-    )
     def _update_experiment_properties_in_db(
-        self, experiment_with_updated_properties: Experiment
+        self,
+        experiment_with_updated_properties: Experiment,
     ) -> bool:
         exp = experiment_with_updated_properties
         if self.db_settings_set:
-            update_properties_on_experiment(
+            _update_experiment_properties_in_db(
                 experiment_with_updated_properties=exp,
-                config=self.db_settings.encoder.config,
+                sqa_config=self.db_settings.encoder.config,
+                suppress_all_errors=self._suppress_all_errors,
             )
             return True
         return False
+
+
+# ------------- Utils for storage that assume `DBSettings` are provided --------
+
+
+@retry_on_exception(
+    retries=3,
+    default_return_on_suppression=False,
+    exception_types=RETRY_EXCEPTION_TYPES,
+)
+def _save_experiment_to_db_if_possible(
+    experiment: Experiment,
+    encoder: Encoder,
+    decoder: Decoder,
+    suppress_all_errors: bool,
+) -> None:
+    start_time = time.time()
+    _save_experiment(
+        experiment,
+        encoder=encoder,
+        decoder=decoder,
+    )
+    logger.debug(
+        f"Saved experiment {experiment.name} in "
+        f"{_round_floats_for_logging(time.time() - start_time)} seconds."
+    )
+
+
+@retry_on_exception(
+    retries=3,
+    default_return_on_suppression=False,
+    exception_types=RETRY_EXCEPTION_TYPES,
+)
+def _save_or_update_trials_in_db_if_possible(
+    experiment: Experiment,
+    trials: List[BaseTrial],
+    encoder: Encoder,
+    decoder: Decoder,
+    suppress_all_errors: bool,
+    reduce_state_generator_runs: bool = False,
+) -> None:
+    start_time = time.time()
+    _save_or_update_trials(
+        experiment=experiment,
+        trials=trials,
+        encoder=encoder,
+        decoder=decoder,
+        batch_size=STORAGE_MINI_BATCH_SIZE,
+        reduce_state_generator_runs=reduce_state_generator_runs,
+    )
+    logger.debug(
+        f"Saved or updated trials {[trial.index for trial in trials]} in "
+        f"{_round_floats_for_logging(time.time() - start_time)} seconds "
+        f"in mini-batches of {STORAGE_MINI_BATCH_SIZE}."
+    )
+
+
+@retry_on_exception(
+    retries=3,
+    default_return_on_suppression=False,
+    exception_types=RETRY_EXCEPTION_TYPES,
+)
+def _save_generation_strategy_to_db_if_possible(
+    generation_strategy: GenerationStrategy,
+    encoder: Encoder,
+    decoder: Decoder,
+    suppress_all_errors: bool,
+) -> None:
+    start_time = time.time()
+    _save_generation_strategy(
+        generation_strategy=generation_strategy,
+        encoder=encoder,
+        decoder=decoder,
+    )
+    logger.debug(
+        f"Saved generation strategy {generation_strategy.name} in "
+        f"{_round_floats_for_logging(time.time() - start_time)} seconds."
+    )
+
+
+@retry_on_exception(
+    retries=3,
+    default_return_on_suppression=False,
+    exception_types=RETRY_EXCEPTION_TYPES,
+)
+def _update_generation_strategy_in_db_if_possible(
+    generation_strategy: GenerationStrategy,
+    new_generator_runs: List[GeneratorRun],
+    encoder: Encoder,
+    decoder: Decoder,
+    suppress_all_errors: bool,
+    reduce_state_generator_runs: bool = False,
+) -> None:
+    start_time = time.time()
+    _update_generation_strategy(
+        generation_strategy=generation_strategy,
+        generator_runs=new_generator_runs,
+        encoder=encoder,
+        decoder=decoder,
+        batch_size=STORAGE_MINI_BATCH_SIZE,
+        reduce_state_generator_runs=reduce_state_generator_runs,
+    )
+    logger.debug(
+        f"Updated generation strategy {generation_strategy.name} in "
+        f"{_round_floats_for_logging(time.time() - start_time)} seconds in "
+        f"mini-batches of {STORAGE_MINI_BATCH_SIZE} generator runs."
+    )
+
+
+@retry_on_exception(
+    retries=3,
+    default_return_on_suppression=False,
+    exception_types=RETRY_EXCEPTION_TYPES,
+)
+def _update_experiment_properties_in_db(
+    experiment_with_updated_properties: Experiment,
+    sqa_config: SQAConfig,
+    suppress_all_errors: bool,
+) -> None:
+    update_properties_on_experiment(
+        experiment_with_updated_properties=experiment_with_updated_properties,
+        config=sqa_config,
+    )
