@@ -85,11 +85,11 @@ from ax.metrics.branin_map import BraninTimestampMapMetric
 from ax.metrics.factorial import FactorialMetric
 from ax.metrics.hartmann6 import AugmentedHartmann6Metric, Hartmann6Metric
 from ax.modelbridge.factory import Cont_X_trans, get_factorial, get_sobol
-from ax.modelbridge.transforms.winsorize import WinsorizationConfig
 from ax.models.torch.botorch_modular.acquisition import Acquisition
 from ax.models.torch.botorch_modular.list_surrogate import ListSurrogate
 from ax.models.torch.botorch_modular.model import BoTorchModel
 from ax.models.torch.botorch_modular.surrogate import Surrogate
+from ax.models.winsorization_config import WinsorizationConfig
 from ax.runners.synthetic import SyntheticRunner
 from ax.service.utils.scheduler_options import SchedulerOptions, TrialType
 from ax.utils.common.logger import get_logger
@@ -554,7 +554,14 @@ def get_experiment_with_observations(
             optimization_config = MultiObjectiveOptimizationConfig(
                 objective=MultiObjective(metrics=metrics),
                 objective_thresholds=[
-                    ObjectiveThreshold(metric=metrics[i], bound=0.0, relative=False)
+                    ObjectiveThreshold(
+                        metric=metrics[i],
+                        bound=0.0,
+                        relative=False,
+                        op=ComparisonOp.LEQ
+                        if metrics[i].lower_is_better
+                        else ComparisonOp.GEQ,
+                    )
                     for i in [0, 1]
                 ],
                 outcome_constraints=[
