@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
-# Copyright (c) Facebook, Inc. and its affiliates.
+# Copyright (c) Meta Platforms, Inc. and affiliates.
 #
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
@@ -12,18 +12,20 @@ from typing import Set
 
 
 # Paths are relative to top-level Ax directory (which is passed into fxn below)
-SPHINX_RST_PATH = os.path.join("sphinx", "source")
+SPHINX_RST_PATH = os.path.join("github", "sphinx", "source")
+
 AX_LIBRARY_PATH = "ax"
 
+# Different because of ShipIt config
+OSS_SPHINX_RST_PATH = os.path.join("sphinx", "source")
+
+
 # Regex for automodule directive used in Sphinx docs
 AUTOMODULE_REGEX = re.compile(r"\.\. automodule:: ([\.\w]*)")
 
 # Modules to exclude from validation
 EXCLUDE_MODULES = {
-    "ax.utils.testing.doctest",
-    "ax.utils.testing.fully_annotated",
     "ax.utils.testing.manifest",
-    "ax.utils.testing.pyre_strict",
 }
 
 
@@ -66,8 +68,16 @@ def validate_complete_sphinx(path_to_ax: str) -> None:
     }
 
     # Load all rst files (these contain the documentation for Sphinx)
-    rstpath = os.path.join(path_to_ax, SPHINX_RST_PATH)
-    rsts = {f.replace(".rst", "") for f in os.listdir(rstpath) if f.endswith(".rst")}
+    try:
+        rstpath = os.path.join(path_to_ax, SPHINX_RST_PATH)
+        rsts = {
+            f.replace(".rst", "") for f in os.listdir(rstpath) if f.endswith(".rst")
+        }
+    except FileNotFoundError:
+        rstpath = os.path.join(path_to_ax, OSS_SPHINX_RST_PATH)
+        rsts = {
+            f.replace(".rst", "") for f in os.listdir(rstpath) if f.endswith(".rst")
+        }
 
     # Verify that all top-level modules have a corresponding rst
     assert len(modules.difference(rsts)) == 0, "Not all modules have corresponding rst."
